# -*- coding: utf-8 -*-
#
# Copyright (c) 2012-2013, CRS4
#
# Permission is hereby granted, free of charge, to any person obtaining a copy of
# this software and associated documentation files (the "Software"), to deal in
# the Software without restriction, including without limitation the rights to
# use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of
# the Software, and to permit persons to whom the Software is furnished to do so,
# subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS
# FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
# COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
# IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
# CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

FIELDS = {'ACC_1': ('leaf', 'TS', 'ACCIDENT_DATE_TIME', None),
 'ACC_2': ('leaf', 'CE', 'ACCIDENT_CODE', None),
 'ACC_3': ('leaf', 'ST', 'ACCIDENT_LOCATION', None),
 'ACC_4': ('leaf', 'CE', 'AUTO_ACCIDENT_STATE', None),
 'ACC_5': ('leaf', 'ID', 'ACCIDENT_JOB_RELATED_INDICATOR', None),
 'ACC_6': ('leaf', 'ID', 'ACCIDENT_DEATH_INDICATOR', None),
 'ADD_1': ('leaf', 'ST', 'ADDENDUM_CONTINUATION_POINTER', None),
 'AIG_1': ('leaf', 'SI', 'SET_ID_AIG', None),
 'AIG_10': ('leaf', 'CE', 'START_DATE_TIME_OFFSET_UNITS', None),
 'AIG_11': ('leaf', 'NM', 'DURATION', None),
 'AIG_12': ('leaf', 'CE', 'DURATION_UNITS', None),
 'AIG_13': ('leaf', 'IS', 'ALLOW_SUBSTITUTION_CODE', None),
 'AIG_14': ('leaf', 'CE', 'FILLER_STATUS_CODE', None),
 'AIG_2': ('leaf', 'ID', 'SEGMENT_ACTION_CODE', None),
 'AIG_3': ('leaf', 'CE', 'RESOURCE_ID', None),
 'AIG_4': ('leaf', 'CE', 'RESOURCE_TYPE', None),
 'AIG_5': ('leaf', 'CE', 'RESOURCE_GROUP', None),
 'AIG_6': ('leaf', 'NM', 'RESOURCE_QUANTITY', None),
 'AIG_7': ('leaf', 'CE', 'RESOURCE_QUANTITY_UNITS', None),
 'AIG_8': ('leaf', 'TS', 'START_DATE_TIME', None),
 'AIG_9': ('leaf', 'NM', 'START_DATE_TIME_OFFSET', None),
 'AIL_1': ('leaf', 'SI', 'SET_ID_AIL', None),
 'AIL_10': ('leaf', 'CE', 'DURATION_UNITS', None),
 'AIL_11': ('leaf', 'IS', 'ALLOW_SUBSTITUTION_CODE', None),
 'AIL_12': ('leaf', 'CE', 'FILLER_STATUS_CODE', None),
 'AIL_2': ('leaf', 'ID', 'SEGMENT_ACTION_CODE', None),
 'AIL_3': ('leaf', 'PL', 'LOCATION_RESOURCE_ID', None),
 'AIL_4': ('leaf', 'CE', 'LOCATION_TYPE_AIL', None),
 'AIL_5': ('leaf', 'CE', 'LOCATION_GROUP', None),
 'AIL_6': ('leaf', 'TS', 'START_DATE_TIME', None),
 'AIL_7': ('leaf', 'NM', 'START_DATE_TIME_OFFSET', None),
 'AIL_8': ('leaf', 'CE', 'START_DATE_TIME_OFFSET_UNITS', None),
 'AIL_9': ('leaf', 'NM', 'DURATION', None),
 'AIP_1': ('leaf', 'SI', 'SET_ID_AIP', None),
 'AIP_10': ('leaf', 'CE', 'DURATION_UNITS', None),
 'AIP_11': ('leaf', 'IS', 'ALLOW_SUBSTITUTION_CODE', None),
 'AIP_12': ('leaf', 'CE', 'FILLER_STATUS_CODE', None),
 'AIP_2': ('leaf', 'ID', 'SEGMENT_ACTION_CODE', None),
 'AIP_3': ('leaf', 'XCN', 'PERSONNEL_RESOURCE_ID', None),
 'AIP_4': ('leaf', 'CE', 'RESOURCE_ROLE', None),
 'AIP_5': ('leaf', 'CE', 'RESOURCE_GROUP', None),
 'AIP_6': ('leaf', 'TS', 'START_DATE_TIME', None),
 'AIP_7': ('leaf', 'NM', 'START_DATE_TIME_OFFSET', None),
 'AIP_8': ('leaf', 'CE', 'START_DATE_TIME_OFFSET_UNITS', None),
 'AIP_9': ('leaf', 'NM', 'DURATION', None),
 'AIS_1': ('leaf', 'SI', 'SET_ID_AIS', None),
 'AIS_10': ('leaf', 'CE', 'FILLER_STATUS_CODE', None),
 'AIS_2': ('leaf', 'ID', 'SEGMENT_ACTION_CODE', None),
 'AIS_3': ('leaf', 'CE', 'UNIVERSAL_SERVICE_ID', None),
 'AIS_4': ('leaf', 'TS', 'START_DATE_TIME', None),
 'AIS_5': ('leaf', 'NM', 'START_DATE_TIME_OFFSET', None),
 'AIS_6': ('leaf', 'CE', 'START_DATE_TIME_OFFSET_UNITS', None),
 'AIS_7': ('leaf', 'NM', 'DURATION', None),
 'AIS_8': ('leaf', 'CE', 'DURATION_UNITS', None),
 'AIS_9': ('leaf', 'IS', 'ALLOW_SUBSTITUTION_CODE', None),
 'AL1_1': ('leaf', 'SI', 'SET_ID_AL1', None),
 'AL1_2': ('leaf', 'IS', 'ALLERGY_TYPE', None),
 'AL1_3': ('leaf', 'CE', 'ALLERGY_CODE_MNEMONIC_DESCRIPTION', None),
 'AL1_4': ('leaf', 'IS', 'ALLERGY_SEVERITY', None),
 'AL1_5': ('leaf', 'ST', 'ALLERGY_REACTION', None),
 'AL1_6': ('leaf', 'DT', 'IDENTIFICATION_DATE', None),
 'APR_1': ('leaf', 'SCV', 'TIME_SELECTION_CRITERIA', None),
 'APR_2': ('leaf', 'SCV', 'RESOURCE_SELECTION_CRITERIA', None),
 'APR_3': ('leaf', 'SCV', 'LOCATION_SELECTION_CRITERIA', None),
 'APR_4': ('leaf', 'NM', 'SLOT_SPACING_CRITERIA', None),
 'APR_5': ('leaf', 'SCV', 'FILLER_OVERRIDE_CRITERIA', None),
 'ARQ_1': ('leaf', 'EI', 'PLACER_APPOINTMENT_ID', None),
 'ARQ_10': ('leaf', 'CE', 'APPOINTMENT_DURATION_UNITS', None),
 'ARQ_11': ('leaf', 'DR', 'REQUESTED_START_DATE_TIME_RANGE', None),
 'ARQ_12': ('leaf', 'ST', 'PRIORITY_ARQ', None),
 'ARQ_13': ('leaf', 'RI', 'REPEATING_INTERVAL', None),
 'ARQ_14': ('leaf', 'ST', 'REPEATING_INTERVAL_DURATION', None),
 'ARQ_15': ('leaf', 'XCN', 'PLACER_CONTACT_PERSON', None),
 'ARQ_16': ('leaf', 'XTN', 'PLACER_CONTACT_PHONE_NUMBER', None),
 'ARQ_17': ('leaf', 'XAD', 'PLACER_CONTACT_ADDRESS', None),
 'ARQ_18': ('leaf', 'PL', 'PLACER_CONTACT_LOCATION', None),
 'ARQ_19': ('leaf', 'XCN', 'ENTERED_BY_PERSON', None),
 'ARQ_2': ('leaf', 'EI', 'FILLER_APPOINTMENT_ID', None),
 'ARQ_20': ('leaf', 'XTN', 'ENTERED_BY_PHONE_NUMBER', None),
 'ARQ_21': ('leaf', 'PL', 'ENTERED_BY_LOCATION', None),
 'ARQ_22': ('leaf', 'EI', 'PARENT_PLACER_APPOINTMENT_ID', None),
 'ARQ_23': ('leaf', 'EI', 'PARENT_FILLER_APPOINTMENT_ID', None),
 'ARQ_3': ('leaf', 'NM', 'OCCURRENCE_NUMBER', None),
 'ARQ_4': ('leaf', 'EI', 'PLACER_GROUP_NUMBER', None),
 'ARQ_5': ('leaf', 'CE', 'SCHEDULE_ID', None),
 'ARQ_6': ('leaf', 'CE', 'REQUEST_EVENT_REASON', None),
 'ARQ_7': ('leaf', 'CE', 'APPOINTMENT_REASON', None),
 'ARQ_8': ('leaf', 'CE', 'APPOINTMENT_TYPE', None),
 'ARQ_9': ('leaf', 'NM', 'APPOINTMENT_DURATION', None),
 'AUT_1': ('leaf', 'CE', 'AUTHORIZING_PAYOR_PLAN_ID', None),
 'AUT_10': ('leaf', 'TS', 'PROCESS_DATE', None),
 'AUT_2': ('leaf', 'CE', 'AUTHORIZING_PAYOR_COMPANY_ID', None),
 'AUT_3': ('leaf', 'ST', 'AUTHORIZING_PAYOR_COMPANY_NAME', None),
 'AUT_4': ('leaf', 'TS', 'AUTHORIZATION_EFFECTIVE_DATE', None),
 'AUT_5': ('leaf', 'TS', 'AUTHORIZATION_EXPIRATION_DATE', None),
 'AUT_6': ('leaf', 'EI', 'AUTHORIZATION_IDENTIFIER', None),
 'AUT_7': ('leaf', 'CP', 'REIMBURSEMENT_LIMIT', None),
 'AUT_8': ('leaf', 'NM', 'REQUESTED_NUMBER_OF_TREATMENTS', None),
 'AUT_9': ('leaf', 'NM', 'AUTHORIZED_NUMBER_OF_TREATMENTS', None),
 'BHS_1': ('leaf', 'ST', 'BATCH_FIELD_SEPARATOR', None),
 'BHS_10': ('leaf', 'ST', 'BATCH_COMMENT', None),
 'BHS_11': ('leaf', 'ST', 'BATCH_CONTROL_ID', None),
 'BHS_12': ('leaf', 'ST', 'REFERENCE_BATCH_CONTROL_ID', None),
 'BHS_2': ('leaf', 'ST', 'BATCH_ENCODING_CHARACTERS', None),
 'BHS_3': ('leaf', 'ST', 'BATCH_SENDING_APPLICATION', None),
 'BHS_4': ('leaf', 'ST', 'BATCH_SENDING_FACILITY', None),
 'BHS_5': ('leaf', 'ST', 'BATCH_RECEIVING_APPLICATION', None),
 'BHS_6': ('leaf', 'ST', 'BATCH_RECEIVING_FACILITY', None),
 'BHS_7': ('leaf', 'TS', 'BATCH_CREATION_DATE_TIME', None),
 'BHS_8': ('leaf', 'ST', 'BATCH_SECURITY', None),
 'BHS_9': ('leaf', 'ST', 'BATCH_NAME_ID_TYPE', None),
 'BLG_1': ('leaf', 'CCD', 'WHEN_TO_CHARGE', None),
 'BLG_2': ('leaf', 'ID', 'CHARGE_TYPE', None),
 'BLG_3': ('leaf', 'CX', 'ACCOUNT_ID', None),
 'BTS_1': ('leaf', 'ST', 'BATCH_MESSAGE_COUNT', None),
 'BTS_2': ('leaf', 'ST', 'BATCH_COMMENT', None),
 'BTS_3': ('leaf', 'NM', 'BATCH_TOTALS', None),
 'CDM_1': ('leaf', 'CE', 'PRIMARY_KEY_VALUE_CDM', None),
 'CDM_10': ('leaf', 'NM', 'RESOURCE_LOAD', None),
 'CDM_11': ('leaf', 'CK', 'CONTRACT_NUMBER', None),
 'CDM_12': ('leaf', 'XON', 'CONTRACT_ORGANIZATION', None),
 'CDM_13': ('leaf', 'ID', 'ROOM_FEE_INDICATOR', None),
 'CDM_2': ('leaf', 'CE', 'CHARGE_CODE_ALIAS', None),
 'CDM_3': ('leaf', 'ST', 'CHARGE_DESCRIPTION_SHORT', None),
 'CDM_4': ('leaf', 'ST', 'CHARGE_DESCRIPTION_LONG', None),
 'CDM_5': ('leaf', 'IS', 'DESCRIPTION_OVERRIDE_INDICATOR', None),
 'CDM_6': ('leaf', 'CE', 'EXPLODING_CHARGES', None),
 'CDM_7': ('leaf', 'CE', 'PROCEDURE_CODE', None),
 'CDM_8': ('leaf', 'ID', 'ACTIVE_INACTIVE_FLAG', None),
 'CDM_9': ('leaf', 'CE', 'INVENTORY_NUMBER', None),
 'CM0_1': ('leaf', 'SI', 'SET_ID_CM0', None),
 'CM0_10': ('leaf', 'XTN', 'CONTACT_S_TEL_NUMBER', None),
 'CM0_11': ('leaf', 'XAD', 'CONTACT_S_ADDRESS', None),
 'CM0_2': ('leaf', 'EI', 'SPONSOR_STUDY_ID', None),
 'CM0_3': ('leaf', 'EI', 'ALTERNATE_STUDY_ID', None),
 'CM0_4': ('leaf', 'ST', 'TITLE_OF_STUDY', None),
 'CM0_5': ('leaf', 'XCN', 'CHAIRMAN_OF_STUDY', None),
 'CM0_6': ('leaf', 'DT', 'LAST_IRB_APPROVAL_DATE', None),
 'CM0_7': ('leaf', 'NM', 'TOTAL_ACCRUAL_TO_DATE', None),
 'CM0_8': ('leaf', 'DT', 'LAST_ACCRUAL_DATE', None),
 'CM0_9': ('leaf', 'XCN', 'CONTACT_FOR_STUDY', None),
 'CM1_1': ('leaf', 'SI', 'SET_ID_CM1', None),
 'CM1_2': ('leaf', 'CE', 'STUDY_PHASE_IDENTIFIER', None),
 'CM1_3': ('leaf', 'ST', 'DESCRIPTION_OF_STUDY_PHASE', None),
 'CM2_1': ('leaf', 'SI', 'SET_ID_CM2', None),
 'CM2_2': ('leaf', 'CE', 'SCHEDULED_TIME_POINT', None),
 'CM2_3': ('leaf', 'ST', 'DESCRIPTION_OF_TIME_POINT', None),
 'CM2_4': ('leaf', 'CE', 'EVENTS_SCHEDULED_THIS_TIME_POINT', None),
 'CSP_1': ('leaf', 'CE', 'STUDY_PHASE_IDENTIFIER', None),
 'CSP_2': ('leaf', 'TS', 'DATE_TIME_STUDY_PHASE_BEGAN', None),
 'CSP_3': ('leaf', 'TS', 'DATE_TIME_STUDY_PHASE_ENDED', None),
 'CSP_4': ('leaf', 'CE', 'STUDY_PHASE_EVALUABILITY', None),
 'CSR_1': ('leaf', 'EI', 'SPONSOR_STUDY_ID', None),
 'CSR_10': ('leaf', 'CE', 'PATIENT_STUDY_ELIGIBILITY_STATUS', None),
 'CSR_11': ('leaf', 'TS', 'STUDY_RANDOMIZATION_DATE_TIME', None),
 'CSR_12': ('leaf', 'CE', 'RANDOMIZED_STUDY_ARM', None),
 'CSR_13': ('leaf', 'CE', 'STRATUM_FOR_STUDY_RANDOMIZATION', None),
 'CSR_14': ('leaf', 'CE', 'PATIENT_EVALUABILITY_STATUS', None),
 'CSR_15': ('leaf', 'TS', 'DATE_TIME_ENDED_STUDY', None),
 'CSR_16': ('leaf', 'CE', 'REASON_ENDED_STUDY', None),
 'CSR_2': ('leaf', 'EI', 'ALTERNATE_STUDY_ID', None),
 'CSR_3': ('leaf', 'CE', 'INSTITUTION_REGISTERING_THE_PATIENT', None),
 'CSR_4': ('leaf', 'CX', 'SPONSOR_PATIENT_ID', None),
 'CSR_5': ('leaf', 'CX', 'ALTERNATE_PATIENT_ID_CSR', None),
 'CSR_6': ('leaf', 'TS', 'DATE_TIME_OF_PATIENT_STUDY_REGISTRATION', None),
 'CSR_7': ('leaf', 'XCN', 'PERSON_PERFORMING_STUDY_REGISTRATION', None),
 'CSR_8': ('leaf', 'XCN', 'STUDY_AUTHORIZING_PROVIDER', None),
 'CSR_9': ('leaf', 'TS', 'DATE_TIME_PATIENT_STUDY_CONSENT_SIGNED', None),
 'CSS_1': ('leaf', 'CE', 'STUDY_SCHEDULED_TIME_POINT', None),
 'CSS_2': ('leaf', 'TS', 'STUDY_SCHEDULED_PATIENT_TIME_POINT', None),
 'CSS_3': ('leaf', 'CE', 'STUDY_QUALITY_CONTROL_CODES', None),
 'CTD_1': ('leaf', 'CE', 'CONTACT_ROLE', None),
 'CTD_2': ('leaf', 'XPN', 'CONTACT_NAME', None),
 'CTD_3': ('leaf', 'XAD', 'CONTACT_ADDRESS', None),
 'CTD_4': ('leaf', 'PL', 'CONTACT_LOCATION', None),
 'CTD_5': ('leaf', 'XTN', 'CONTACT_COMMUNICATION_INFORMATION', None),
 'CTD_6': ('leaf', 'CE', 'PREFERRED_METHOD_OF_CONTACT', None),
 'CTD_7': ('leaf', 'PI', 'CONTACT_IDENTIFIERS', None),
 'CTI_1': ('leaf', 'EI', 'SPONSOR_STUDY_ID', None),
 'CTI_2': ('leaf', 'CE', 'STUDY_PHASE_IDENTIFIER', None),
 'CTI_3': ('leaf', 'CE', 'STUDY_SCHEDULED_TIME_POINT', None),
 'DB1_1': ('leaf', 'SI', 'SET_ID_DB1', None),
 'DB1_2': ('leaf', 'IS', 'DISABLED_PERSON_CODE', None),
 'DB1_3': ('leaf', 'CX', 'DISABLED_PERSON_IDENTIFIER', None),
 'DB1_4': ('leaf', 'ID', 'DISABLED_INDICATOR', None),
 'DB1_5': ('leaf', 'DT', 'DISABILITY_START_DATE', None),
 'DB1_6': ('leaf', 'DT', 'DISABILITY_END_DATE', None),
 'DB1_7': ('leaf', 'DT', 'DISABILITY_RETURN_TO_WORK_DATE', None),
 'DB1_8': ('leaf', 'DT', 'DISABILITY_UNABLE_TO_WORK_DATE', None),
 'DG1_1': ('leaf', 'SI', 'SET_ID_DG1', None),
 'DG1_10': ('leaf', 'IS', 'DRG_GROUPER_REVIEW_CODE', None),
 'DG1_11': ('leaf', 'CE', 'OUTLIER_TYPE', None),
 'DG1_12': ('leaf', 'NM', 'OUTLIER_DAYS', None),
 'DG1_13': ('leaf', 'CP', 'OUTLIER_COST', None),
 'DG1_14': ('leaf', 'ST', 'GROUPER_VERSION_AND_TYPE', None),
 'DG1_15': ('leaf', 'ID', 'DIAGNOSIS_PRIORITY', None),
 'DG1_16': ('leaf', 'XCN', 'DIAGNOSING_CLINICIAN', None),
 'DG1_17': ('leaf', 'IS', 'DIAGNOSIS_CLASSIFICATION', None),
 'DG1_18': ('leaf', 'ID', 'CONFIDENTIAL_INDICATOR', None),
 'DG1_19': ('leaf', 'TS', 'ATTESTATION_DATE_TIME', None),
 'DG1_2': ('leaf', 'ID', 'DIAGNOSIS_CODING_METHOD', None),
 'DG1_3': ('leaf', 'CE', 'DIAGNOSIS_CODE_DG1', None),
 'DG1_4': ('leaf', 'ST', 'DIAGNOSIS_DESCRIPTION', None),
 'DG1_5': ('leaf', 'TS', 'DIAGNOSIS_DATE_TIME', None),
 'DG1_6': ('leaf', 'IS', 'DIAGNOSIS_TYPE', None),
 'DG1_7': ('leaf', 'CE', 'MAJOR_DIAGNOSTIC_CATEGORY', None),
 'DG1_8': ('leaf', 'CE', 'DIAGNOSTIC_RELATED_GROUP', None),
 'DG1_9': ('leaf', 'ID', 'DRG_APPROVAL_INDICATOR', None),
 'DRG_1': ('leaf', 'CE', 'DIAGNOSTIC_RELATED_GROUP', None),
 'DRG_10': ('leaf', 'ID', 'CONFIDENTIAL_INDICATOR', None),
 'DRG_2': ('leaf', 'TS', 'DRG_ASSIGNED_DATE_TIME', None),
 'DRG_3': ('leaf', 'ID', 'DRG_APPROVAL_INDICATOR', None),
 'DRG_4': ('leaf', 'IS', 'DRG_GROUPER_REVIEW_CODE', None),
 'DRG_5': ('leaf', 'CE', 'OUTLIER_TYPE', None),
 'DRG_6': ('leaf', 'NM', 'OUTLIER_DAYS', None),
 'DRG_7': ('leaf', 'CP', 'OUTLIER_COST', None),
 'DRG_8': ('leaf', 'IS', 'DRG_PAYOR', None),
 'DRG_9': ('leaf', 'CP', 'OUTLIER_REIMBURSEMENT', None),
 'DSC_1': ('leaf', 'ST', 'CONTINUATION_POINTER', None),
 'DSP_1': ('leaf', 'SI', 'SET_ID_DSP', None),
 'DSP_2': ('leaf', 'SI', 'DISPLAY_LEVEL', None),
 'DSP_3': ('leaf', 'TX', 'DATA_LINE', None),
 'DSP_4': ('leaf', 'ST', 'LOGICAL_BREAK_POINT', None),
 'DSP_5': ('leaf', 'TX', 'RESULT_ID', None),
 'EQL_1': ('leaf', 'ST', 'QUERY_TAG', None),
 'EQL_2': ('leaf', 'ID', 'QUERY_RESPONSE_FORMAT_CODE', None),
 'EQL_3': ('leaf', 'CE', 'EQL_QUERY_NAME', None),
 'EQL_4': ('leaf', 'ST', 'EQL_QUERY_STATEMENT', None),
 'ERQ_1': ('leaf', 'ST', 'QUERY_TAG', None),
 'ERQ_2': ('leaf', 'CE', 'EVENT_IDENTIFIER', None),
 'ERQ_3': ('leaf', 'QIP', 'INPUT_PARAMETER_LIST', None),
 'ERR_1': ('leaf', 'ELD', 'ERROR_CODE_AND_LOCATION', None),
 'EVN_1': ('leaf', 'ID', 'EVENT_TYPE_CODE', None),
 'EVN_2': ('leaf', 'TS', 'RECORDED_DATE_TIME', None),
 'EVN_3': ('leaf', 'TS', 'DATE_TIME_PLANNED_EVENT', None),
 'EVN_4': ('leaf', 'IS', 'EVENT_REASON_CODE', None),
 'EVN_5': ('leaf', 'XCN', 'OPERATOR_ID', None),
 'EVN_6': ('leaf', 'TS', 'EVENT_OCCURRED', None),
 'FAC_1': ('leaf', 'EI', 'FACILITY_ID_FAC', None),
 'FAC_10': ('leaf', 'ST', 'SIGNATURE_AUTHORITY_TITLE', None),
 'FAC_11': ('leaf', 'XAD', 'SIGNATURE_AUTHORITY_ADDRESS', None),
 'FAC_12': ('leaf', 'XTN', 'SIGNATURE_AUTHORITY_TELECOMMUNICATION', None),
 'FAC_2': ('leaf', 'ID', 'FACILITY_TYPE', None),
 'FAC_3': ('leaf', 'XAD', 'FACILITY_ADDRESS', None),
 'FAC_4': ('leaf', 'XTN', 'FACILITY_TELECOMMUNICATION', None),
 'FAC_5': ('leaf', 'XCN', 'CONTACT_PERSON', None),
 'FAC_6': ('leaf', 'ST', 'CONTACT_TITLE', None),
 'FAC_7': ('leaf', 'XAD', 'CONTACT_ADDRESS', None),
 'FAC_8': ('leaf', 'XTN', 'CONTACT_TELECOMMUNICATION', None),
 'FAC_9': ('leaf', 'XCN', 'SIGNATURE_AUTHORITY', None),
 'FHS_1': ('leaf', 'ST', 'FILE_FIELD_SEPARATOR', None),
 'FHS_10': ('leaf', 'ST', 'FILE_HEADER_COMMENT', None),
 'FHS_11': ('leaf', 'ST', 'FILE_CONTROL_ID', None),
 'FHS_12': ('leaf', 'ST', 'REFERENCE_FILE_CONTROL_ID', None),
 'FHS_2': ('leaf', 'ST', 'FILE_ENCODING_CHARACTERS', None),
 'FHS_3': ('leaf', 'ST', 'FILE_SENDING_APPLICATION', None),
 'FHS_4': ('leaf', 'ST', 'FILE_SENDING_FACILITY', None),
 'FHS_5': ('leaf', 'ST', 'FILE_RECEIVING_APPLICATION', None),
 'FHS_6': ('leaf', 'ST', 'FILE_RECEIVING_FACILITY', None),
 'FHS_7': ('leaf', 'TS', 'FILE_CREATION_DATE_TIME', None),
 'FHS_8': ('leaf', 'ST', 'FILE_SECURITY', None),
 'FHS_9': ('leaf', 'ST', 'FILE_NAME_ID', None),
 'FT1_1': ('leaf', 'SI', 'SET_ID_FT1', None),
 'FT1_10': ('leaf', 'NM', 'TRANSACTION_QUANTITY', None),
 'FT1_11': ('leaf', 'CP', 'TRANSACTION_AMOUNT_EXTENDED', None),
 'FT1_12': ('leaf', 'CP', 'TRANSACTION_AMOUNT_UNIT', None),
 'FT1_13': ('leaf', 'CE', 'DEPARTMENT_CODE', None),
 'FT1_14': ('leaf', 'CE', 'INSURANCE_PLAN_ID', None),
 'FT1_15': ('leaf', 'CP', 'INSURANCE_AMOUNT', None),
 'FT1_16': ('leaf', 'PL', 'ASSIGNED_PATIENT_LOCATION', None),
 'FT1_17': ('leaf', 'IS', 'FEE_SCHEDULE', None),
 'FT1_18': ('leaf', 'IS', 'PATIENT_TYPE', None),
 'FT1_19': ('leaf', 'CE', 'DIAGNOSIS_CODE_FT1', None),
 'FT1_2': ('leaf', 'ST', 'TRANSACTION_ID', None),
 'FT1_20': ('leaf', 'XCN', 'PERFORMED_BY_CODE', None),
 'FT1_21': ('leaf', 'XCN', 'ORDERED_BY_CODE', None),
 'FT1_22': ('leaf', 'CP', 'UNIT_COST', None),
 'FT1_23': ('leaf', 'EI', 'FILLER_ORDER_NUMBER', None),
 'FT1_24': ('leaf', 'XCN', 'ENTERED_BY_CODE', None),
 'FT1_25': ('leaf', 'CE', 'PROCEDURE_CODE', None),
 'FT1_26': ('leaf', 'CE', 'PROCEDURE_CODE_MODIFIER', None),
 'FT1_3': ('leaf', 'ST', 'TRANSACTION_BATCH_ID', None),
 'FT1_4': ('leaf', 'TS', 'TRANSACTION_DATE', None),
 'FT1_5': ('leaf', 'TS', 'TRANSACTION_POSTING_DATE', None),
 'FT1_6': ('leaf', 'IS', 'TRANSACTION_TYPE', None),
 'FT1_7': ('leaf', 'CE', 'TRANSACTION_CODE', None),
 'FT1_8': ('leaf', 'ST', 'TRANSACTION_DESCRIPTION', None),
 'FT1_9': ('leaf', 'ST', 'TRANSACTION_DESCRIPTION_ALT', None),
 'FTS_1': ('leaf', 'NM', 'FILE_BATCH_COUNT', None),
 'FTS_2': ('leaf', 'ST', 'FILE_TRAILER_COMMENT', None),
 'GOL_1': ('leaf', 'ID', 'ACTION_CODE', None),
 'GOL_10': ('leaf', 'CE', 'GOAL_MANAGEMENT_DISCIPLINE', None),
 'GOL_11': ('leaf', 'CE', 'CURRENT_GOAL_REVIEW_STATUS', None),
 'GOL_12': ('leaf', 'TS', 'CURRENT_GOAL_REVIEW_DATE_TIME', None),
 'GOL_13': ('leaf', 'TS', 'NEXT_GOAL_REVIEW_DATE_TIME', None),
 'GOL_14': ('leaf', 'TS', 'PREVIOUS_GOAL_REVIEW_DATE_TIME', None),
 'GOL_15': ('leaf', 'TQ', 'GOAL_REVIEW_INTERVAL', None),
 'GOL_16': ('leaf', 'CE', 'GOAL_EVALUATION', None),
 'GOL_17': ('leaf', 'ST', 'GOAL_EVALUATION_COMMENT', None),
 'GOL_18': ('leaf', 'CE', 'GOAL_LIFE_CYCLE_STATUS', None),
 'GOL_19': ('leaf', 'TS', 'GOAL_LIFE_CYCLE_STATUS_DATE_TIME', None),
 'GOL_2': ('leaf', 'TS', 'ACTION_DATE_TIME', None),
 'GOL_20': ('leaf', 'CE', 'GOAL_TARGET_TYPE', None),
 'GOL_21': ('leaf', 'XPN', 'GOAL_TARGET_NAME', None),
 'GOL_3': ('leaf', 'CE', 'GOAL_ID', None),
 'GOL_4': ('leaf', 'EI', 'GOAL_INSTANCE_ID', None),
 'GOL_5': ('leaf', 'EI', 'EPISODE_OF_CARE_ID', None),
 'GOL_6': ('leaf', 'NM', 'GOAL_LIST_PRIORITY', None),
 'GOL_7': ('leaf', 'TS', 'GOAL_ESTABLISHED_DATE_TIME', None),
 'GOL_8': ('leaf', 'TS', 'EXPECTED_GOAL_ACHIEVE_DATE_TIME', None),
 'GOL_9': ('leaf', 'CE', 'GOAL_CLASSIFICATION', None),
 'GT1_1': ('leaf', 'SI', 'SET_ID_GT1', None),
 'GT1_10': ('leaf', 'IS', 'GUARANTOR_TYPE', None),
 'GT1_11': ('leaf', 'CE', 'GUARANTOR_RELATIONSHIP', None),
 'GT1_12': ('leaf', 'ST', 'GUARANTOR_SSN', None),
 'GT1_13': ('leaf', 'DT', 'GUARANTOR_DATE_BEGIN', None),
 'GT1_14': ('leaf', 'DT', 'GUARANTOR_DATE_END', None),
 'GT1_15': ('leaf', 'NM', 'GUARANTOR_PRIORITY', None),
 'GT1_16': ('leaf', 'XPN', 'GUARANTOR_EMPLOYER_NAME', None),
 'GT1_17': ('leaf', 'XAD', 'GUARANTOR_EMPLOYER_ADDRESS', None),
 'GT1_18': ('leaf', 'XTN', 'GUARANTOR_EMPLOYER_PHONE_NUMBER', None),
 'GT1_19': ('leaf', 'CX', 'GUARANTOR_EMPLOYEE_ID_NUMBER', None),
 'GT1_2': ('leaf', 'CX', 'GUARANTOR_NUMBER', None),
 'GT1_20': ('leaf', 'IS', 'GUARANTOR_EMPLOYMENT_STATUS', None),
 'GT1_21': ('leaf', 'XON', 'GUARANTOR_ORGANIZATION_NAME', None),
 'GT1_22': ('leaf', 'ID', 'GUARANTOR_BILLING_HOLD_FLAG', None),
 'GT1_23': ('leaf', 'CE', 'GUARANTOR_CREDIT_RATING_CODE', None),
 'GT1_24': ('leaf', 'TS', 'GUARANTOR_DEATH_DATE_AND_TIME', None),
 'GT1_25': ('leaf', 'ID', 'GUARANTOR_DEATH_FLAG', None),
 'GT1_26': ('leaf', 'CE', 'GUARANTOR_CHARGE_ADJUSTMENT_CODE', None),
 'GT1_27': ('leaf', 'CP', 'GUARANTOR_HOUSEHOLD_ANNUAL_INCOME', None),
 'GT1_28': ('leaf', 'NM', 'GUARANTOR_HOUSEHOLD_SIZE', None),
 'GT1_29': ('leaf', 'CX', 'GUARANTOR_EMPLOYER_ID_NUMBER', None),
 'GT1_3': ('leaf', 'XPN', 'GUARANTOR_NAME', None),
 'GT1_30': ('leaf', 'CE', 'GUARANTOR_MARITAL_STATUS_CODE', None),
 'GT1_31': ('leaf', 'DT', 'GUARANTOR_HIRE_EFFECTIVE_DATE', None),
 'GT1_32': ('leaf', 'DT', 'EMPLOYMENT_STOP_DATE', None),
 'GT1_33': ('leaf', 'IS', 'LIVING_DEPENDENCY', None),
 'GT1_34': ('leaf', 'IS', 'AMBULATORY_STATUS', None),
 'GT1_35': ('leaf', 'CE', 'CITIZENSHIP', None),
 'GT1_36': ('leaf', 'CE', 'PRIMARY_LANGUAGE', None),
 'GT1_37': ('leaf', 'IS', 'LIVING_ARRANGEMENT', None),
 'GT1_38': ('leaf', 'CE', 'PUBLICITY_CODE', None),
 'GT1_39': ('leaf', 'ID', 'PROTECTION_INDICATOR', None),
 'GT1_4': ('leaf', 'XPN', 'GUARANTOR_SPOUSE_NAME', None),
 'GT1_40': ('leaf', 'IS', 'STUDENT_INDICATOR', None),
 'GT1_41': ('leaf', 'CE', 'RELIGION', None),
 'GT1_42': ('leaf', 'XPN', u'MOTHER_S_MAIDEN_NAME', None),
 'GT1_43': ('leaf', 'CE', 'NATIONALITY', None),
 'GT1_44': ('leaf', 'CE', 'ETHNIC_GROUP', None),
 'GT1_45': ('leaf', 'XPN', u'CONTACT_PERSON_S_NAME', None),
 'GT1_46': ('leaf', 'XTN', u'CONTACT_PERSON_S_TELEPHONE_NUMBER', None),
 'GT1_47': ('leaf', 'CE', 'CONTACT_REASON', None),
 'GT1_48': ('leaf', 'IS', 'CONTACT_RELATIONSHIP', None),
 'GT1_49': ('leaf', 'ST', 'JOB_TITLE', None),
 'GT1_5': ('leaf', 'XAD', 'GUARANTOR_ADDRESS', None),
 'GT1_50': ('leaf', 'JCC', 'JOB_CODE_CLASS', None),
 'GT1_51': ('leaf', 'XON', u'GUARANTOR_EMPLOYER_S_ORGANIZATION_NAME', None),
 'GT1_52': ('leaf', 'IS', 'HANDICAP', None),
 'GT1_53': ('leaf', 'IS', 'JOB_STATUS', None),
 'GT1_54': ('leaf', 'FC', 'GUARANTOR_FINANCIAL_CLASS', None),
 'GT1_55': ('leaf', 'CE', 'GUARANTOR_RACE', None),
 'GT1_6': ('leaf', 'XTN', 'GUARANTOR_PH_NUM_HOME', None),
 'GT1_7': ('leaf', 'XTN', 'GUARANTOR_PH_NUM_BUSINESS', None),
 'GT1_8': ('leaf', 'TS', 'GUARANTOR_DATE_TIME_OF_BIRTH', None),
 'GT1_9': ('leaf', 'IS', 'GUARANTOR_SEX', None),
 'IN1_1': ('leaf', 'SI', 'SET_ID_IN1', None),
 'IN1_10': ('leaf', 'CX', u'INSURED_S_GROUP_EMP_ID', None),
 'IN1_11': ('leaf', 'XON', u'INSURED_S_GROUP_EMP_NAME', None),
 'IN1_12': ('leaf', 'DT', 'PLAN_EFFECTIVE_DATE', None),
 'IN1_13': ('leaf', 'DT', 'PLAN_EXPIRATION_DATE', None),
 'IN1_14': ('leaf', 'AUI', 'AUTHORIZATION_INFORMATION', None),
 'IN1_15': ('leaf', 'IS', 'PLAN_TYPE', None),
 'IN1_16': ('leaf', 'XPN', 'NAME_OF_INSURED', None),
 'IN1_17': ('leaf', 'CE', u'INSURED_S_RELATIONSHIP_TO_PATIENT', None),
 'IN1_18': ('leaf', 'TS', u'INSURED_S_DATE_OF_BIRTH', None),
 'IN1_19': ('leaf', 'XAD', u'INSURED_S_ADDRESS', None),
 'IN1_2': ('leaf', 'CE', 'INSURANCE_PLAN_ID', None),
 'IN1_20': ('leaf', 'IS', 'ASSIGNMENT_OF_BENEFITS', None),
 'IN1_21': ('leaf', 'IS', 'COORDINATION_OF_BENEFITS', None),
 'IN1_22': ('leaf', 'ST', 'COORD_OF_BEN_PRIORITY', None),
 'IN1_23': ('leaf', 'ID', 'NOTICE_OF_ADMISSION_FLAG', None),
 'IN1_24': ('leaf', 'DT', 'NOTICE_OF_ADMISSION_DATE', None),
 'IN1_25': ('leaf', 'ID', 'REPORT_OF_ELIGIBILITY_FLAG', None),
 'IN1_26': ('leaf', 'DT', 'REPORT_OF_ELIGIBILITY_DATE', None),
 'IN1_27': ('leaf', 'IS', 'RELEASE_INFORMATION_CODE', None),
 'IN1_28': ('leaf', 'ST', 'PRE_ADMIT_CERT_PAC_', None),
 'IN1_29': ('leaf', 'TS', 'VERIFICATION_DATE_TIME', None),
 'IN1_3': ('leaf', 'CX', 'INSURANCE_COMPANY_ID', None),
 'IN1_30': ('leaf', 'XCN', 'VERIFICATION_BY', None),
 'IN1_31': ('leaf', 'IS', 'TYPE_OF_AGREEMENT_CODE', None),
 'IN1_32': ('leaf', 'IS', 'BILLING_STATUS', None),
 'IN1_33': ('leaf', 'NM', 'LIFETIME_RESERVE_DAYS', None),
 'IN1_34': ('leaf', 'NM', 'DELAY_BEFORE_L_R_DAY', None),
 'IN1_35': ('leaf', 'IS', 'COMPANY_PLAN_CODE', None),
 'IN1_36': ('leaf', 'ST', 'POLICY_NUMBER', None),
 'IN1_37': ('leaf', 'CP', 'POLICY_DEDUCTIBLE', None),
 'IN1_38': ('leaf', 'CP', 'POLICY_LIMIT_AMOUNT', None),
 'IN1_39': ('leaf', 'NM', 'POLICY_LIMIT_DAYS', None),
 'IN1_4': ('leaf', 'XON', 'INSURANCE_COMPANY_NAME', None),
 'IN1_40': ('leaf', 'CP', 'ROOM_RATE_SEMI_PRIVATE', None),
 'IN1_41': ('leaf', 'CP', 'ROOM_RATE_PRIVATE', None),
 'IN1_42': ('leaf', 'CE', u'INSURED_S_EMPLOYMENT_STATUS', None),
 'IN1_43': ('leaf', 'IS', u'INSURED_S_SEX', None),
 'IN1_44': ('leaf', 'XAD', u'INSURED_S_EMPLOYER_S_ADDRESS', None),
 'IN1_45': ('leaf', 'ST', 'VERIFICATION_STATUS', None),
 'IN1_46': ('leaf', 'IS', 'PRIOR_INSURANCE_PLAN_ID', None),
 'IN1_47': ('leaf', 'IS', 'COVERAGE_TYPE', None),
 'IN1_48': ('leaf', 'IS', 'HANDICAP', None),
 'IN1_49': ('leaf', 'CX', u'INSURED_S_ID_NUMBER', None),
 'IN1_5': ('leaf', 'XAD', 'INSURANCE_COMPANY_ADDRESS', None),
 'IN1_6': ('leaf', 'XPN', 'INSURANCE_CO_CONTACT_PERSON', None),
 'IN1_7': ('leaf', 'XTN', 'INSURANCE_CO_PHONE_NUMBER', None),
 'IN1_8': ('leaf', 'ST', 'GROUP_NUMBER', None),
 'IN1_9': ('leaf', 'XON', 'GROUP_NAME', None),
 'IN2_1': ('leaf', 'CX', u'INSURED_S_EMPLOYEE_ID', None),
 'IN2_10': ('leaf', 'ST', 'MILITARY_ID_NUMBER', None),
 'IN2_11': ('leaf', 'CE', 'DEPENDENT_OF_MILITARY_RECIPIENT', None),
 'IN2_12': ('leaf', 'ST', 'MILITARY_ORGANIZATION', None),
 'IN2_13': ('leaf', 'ST', 'MILITARY_STATION', None),
 'IN2_14': ('leaf', 'IS', 'MILITARY_SERVICE', None),
 'IN2_15': ('leaf', 'IS', 'MILITARY_RANK_GRADE', None),
 'IN2_16': ('leaf', 'IS', 'MILITARY_STATUS', None),
 'IN2_17': ('leaf', 'DT', 'MILITARY_RETIRE_DATE', None),
 'IN2_18': ('leaf', 'ID', 'MILITARY_NON_AVAIL_CERT_ON_FILE', None),
 'IN2_19': ('leaf', 'ID', 'BABY_COVERAGE', None),
 'IN2_2': ('leaf', 'ST', u'INSURED_S_SOCIAL_SECURITY_NUMBER', None),
 'IN2_20': ('leaf', 'ID', 'COMBINE_BABY_BILL', None),
 'IN2_21': ('leaf', 'ST', 'BLOOD_DEDUCTIBLE', None),
 'IN2_22': ('leaf', 'XPN', 'SPECIAL_COVERAGE_APPROVAL_NAME', None),
 'IN2_23': ('leaf', 'ST', 'SPECIAL_COVERAGE_APPROVAL_TITLE', None),
 'IN2_24': ('leaf', 'IS', 'NON_COVERED_INSURANCE_CODE', None),
 'IN2_25': ('leaf', 'CX', 'PAYOR_ID', None),
 'IN2_26': ('leaf', 'CX', 'PAYOR_SUBSCRIBER_ID', None),
 'IN2_27': ('leaf', 'IS', 'ELIGIBILITY_SOURCE', None),
 'IN2_28': ('leaf', 'RMC', 'ROOM_COVERAGE_TYPE_AMOUNT', None),
 'IN2_29': ('leaf', 'PTA', 'POLICY_TYPE_AMOUNT', None),
 'IN2_3': ('leaf', 'XCN', u'INSURED_S_EMPLOYER_S_NAME_AND_ID', None),
 'IN2_30': ('leaf', 'DDI', 'DAILY_DEDUCTIBLE', None),
 'IN2_31': ('leaf', 'IS', 'LIVING_DEPENDENCY', None),
 'IN2_32': ('leaf', 'IS', 'AMBULATORY_STATUS', None),
 'IN2_33': ('leaf', 'CE', 'CITIZENSHIP', None),
 'IN2_34': ('leaf', 'CE', 'PRIMARY_LANGUAGE', None),
 'IN2_35': ('leaf', 'IS', 'LIVING_ARRANGEMENT', None),
 'IN2_36': ('leaf', 'CE', 'PUBLICITY_CODE', None),
 'IN2_37': ('leaf', 'ID', 'PROTECTION_INDICATOR', None),
 'IN2_38': ('leaf', 'IS', 'STUDENT_INDICATOR', None),
 'IN2_39': ('leaf', 'CE', 'RELIGION', None),
 'IN2_4': ('leaf', 'IS', 'EMPLOYER_INFORMATION_DATA', None),
 'IN2_40': ('leaf', 'XPN', u'MOTHER_S_MAIDEN_NAME', None),
 'IN2_41': ('leaf', 'CE', 'NATIONALITY', None),
 'IN2_42': ('leaf', 'CE', 'ETHNIC_GROUP', None),
 'IN2_43': ('leaf', 'CE', 'MARITAL_STATUS', None),
 'IN2_44': ('leaf', 'DT', u'INSURED_S_EMPLOYMENT_START_DATE', None),
 'IN2_45': ('leaf', 'DT', 'EMPLOYMENT_STOP_DATE', None),
 'IN2_46': ('leaf', 'ST', 'JOB_TITLE', None),
 'IN2_47': ('leaf', 'JCC', 'JOB_CODE_CLASS', None),
 'IN2_48': ('leaf', 'IS', 'JOB_STATUS', None),
 'IN2_49': ('leaf', 'XPN', 'EMPLOYER_CONTACT_PERSON_NAME', None),
 'IN2_5': ('leaf', 'IS', 'MAIL_CLAIM_PARTY', None),
 'IN2_50': ('leaf', 'XTN', 'EMPLOYER_CONTACT_PERSON_PHONE_NUMBER', None),
 'IN2_51': ('leaf', 'IS', 'EMPLOYER_CONTACT_REASON', None),
 'IN2_52': ('leaf', 'XPN', u'INSURED_S_CONTACT_PERSON_S_NAME', None),
 'IN2_53': ('leaf', 'XTN', u'INSURED_S_CONTACT_PERSON_PHONE_NUMBER', None),
 'IN2_54': ('leaf', 'IS', u'INSURED_S_CONTACT_PERSON_REASON', None),
 'IN2_55': ('leaf', 'DT', 'RELATIONSHIP_TO_THE_PATIENT_START_DATE', None),
 'IN2_56': ('leaf', 'DT', 'RELATIONSHIP_TO_THE_PATIENT_STOP_DATE', None),
 'IN2_57': ('leaf', 'IS', 'INSURANCE_CO_CONTACT_REASON', None),
 'IN2_58': ('leaf', 'XTN', 'INSURANCE_CO_CONTACT_PHONE_NUMBER', None),
 'IN2_59': ('leaf', 'IS', 'POLICY_SCOPE', None),
 'IN2_6': ('leaf', 'ST', 'MEDICARE_HEALTH_INS_CARD_NUMBER', None),
 'IN2_60': ('leaf', 'IS', 'POLICY_SOURCE', None),
 'IN2_61': ('leaf', 'CX', 'PATIENT_MEMBER_NUMBER', None),
 'IN2_62': ('leaf', 'CE', u'GUARANTOR_S_RELATIONSHIP_TO_INSURED', None),
 'IN2_63': ('leaf', 'XTN', u'INSURED_S_PHONE_NUMBER_HOME', None),
 'IN2_64': ('leaf', 'XTN', u'INSURED_S_EMPLOYER_PHONE_NUMBER', None),
 'IN2_65': ('leaf', 'CE', 'MILITARY_HANDICAPPED_PROGRAM', None),
 'IN2_66': ('leaf', 'ID', 'SUSPEND_FLAG', None),
 'IN2_67': ('leaf', 'ID', 'COPAY_LIMIT_FLAG', None),
 'IN2_68': ('leaf', 'ID', 'STOPLOSS_LIMIT_FLAG', None),
 'IN2_69': ('leaf', 'XON', 'INSURED_ORGANIZATION_NAME_AND_ID', None),
 'IN2_7': ('leaf', 'XPN', 'MEDICAID_CASE_NAME', None),
 'IN2_70': ('leaf', 'XON', 'INSURED_EMPLOYER_ORGANIZATION_NAME_AND_ID', None),
 'IN2_71': ('leaf', 'CE', 'RACE', None),
 'IN2_72': ('leaf', 'CE', u'HCFA_PATIENT_S_RELATIONSHIP_TO_INSURED', None),
 'IN2_8': ('leaf', 'ST', 'MEDICAID_CASE_NUMBER', None),
 'IN2_9': ('leaf', 'XPN', 'MILITARY_SPONSOR_NAME', None),
 'IN3_1': ('leaf', 'SI', 'SET_ID_IN3', None),
 'IN3_10': ('leaf', 'DT', 'CERTIFICATION_END_DATE', None),
 'IN3_11': ('leaf', 'DTN', 'DAYS', None),
 'IN3_12': ('leaf', 'CE', 'NON_CONCUR_CODE_DESCRIPTION', None),
 'IN3_13': ('leaf', 'TS', 'NON_CONCUR_EFFECTIVE_DATE_TIME', None),
 'IN3_14': ('leaf', 'XCN', 'PHYSICIAN_REVIEWER', None),
 'IN3_15': ('leaf', 'ST', 'CERTIFICATION_CONTACT', None),
 'IN3_16': ('leaf', 'XTN', 'CERTIFICATION_CONTACT_PHONE_NUMBER', None),
 'IN3_17': ('leaf', 'CE', 'APPEAL_REASON', None),
 'IN3_18': ('leaf', 'CE', 'CERTIFICATION_AGENCY', None),
 'IN3_19': ('leaf', 'XTN', 'CERTIFICATION_AGENCY_PHONE_NUMBER', None),
 'IN3_2': ('leaf', 'CX', 'CERTIFICATION_NUMBER', None),
 'IN3_20': ('leaf', 'PCF', 'PRE_CERTIFICATION_REQ_WINDOW', None),
 'IN3_21': ('leaf', 'ST', 'CASE_MANAGER', None),
 'IN3_22': ('leaf', 'DT', 'SECOND_OPINION_DATE', None),
 'IN3_23': ('leaf', 'IS', 'SECOND_OPINION_STATUS', None),
 'IN3_24': ('leaf', 'IS', 'SECOND_OPINION_DOCUMENTATION_RECEIVED', None),
 'IN3_25': ('leaf', 'XCN', 'SECOND_OPINION_PHYSICIAN', None),
 'IN3_3': ('leaf', 'XCN', 'CERTIFIED_BY', None),
 'IN3_4': ('leaf', 'ID', 'CERTIFICATION_REQUIRED', None),
 'IN3_5': ('leaf', 'MOP', 'PENALTY', None),
 'IN3_6': ('leaf', 'TS', 'CERTIFICATION_DATE_TIME', None),
 'IN3_7': ('leaf', 'TS', 'CERTIFICATION_MODIFY_DATE_TIME', None),
 'IN3_8': ('leaf', 'XCN', 'OPERATOR', None),
 'IN3_9': ('leaf', 'DT', 'CERTIFICATION_BEGIN_DATE', None),
 'LCC_1': ('leaf', 'PL', 'PRIMARY_KEY_VALUE_LCC', None),
 'LCC_2': ('leaf', 'IS', 'LOCATION_DEPARTMENT', None),
 'LCC_3': ('leaf', 'CE', 'ACCOMMODATION_TYPE', None),
 'LCC_4': ('leaf', 'CE', 'CHARGE_CODE', None),
 'LCH_1': ('leaf', 'PL', 'PRIMARY_KEY_VALUE_LCH', None),
 'LCH_2': ('leaf', 'ID', 'SEGMENT_ACTION_CODE', None),
 'LCH_3': ('leaf', 'EI', 'SEGMENT_UNIQUE_KEY', None),
 'LCH_4': ('leaf', 'CE', 'LOCATION_CHARACTERISTIC_ID', None),
 'LCH_5': ('leaf', 'CE', 'LOCATION_CHARACTERISTIC_VALUE', None),
 'LDP_1': ('leaf', 'PL', 'PRIMARY_KEY_VALUE_LDP', None),
 'LDP_10': ('leaf', 'VH', 'VISITING_HOURS', None),
 'LDP_11': ('leaf', 'XTN', 'CONTACT_PHONE', None),
 'LDP_2': ('leaf', 'IS', 'LOCATION_DEPARTMENT', None),
 'LDP_3': ('leaf', 'IS', 'LOCATION_SERVICE', None),
 'LDP_4': ('leaf', 'CE', 'SPECIALTY_TYPE', None),
 'LDP_5': ('leaf', 'IS', 'VALID_PATIENT_CLASSES', None),
 'LDP_6': ('leaf', 'ID', 'ACTIVE_INACTIVE_FLAG', None),
 'LDP_7': ('leaf', 'TS', 'ACTIVATION_DATE_LDP', None),
 'LDP_8': ('leaf', 'TS', 'INACTIVATION_DATE_LDP', None),
 'LDP_9': ('leaf', 'ST', 'INACTIVATED_REASON', None),
 'LOC_1': ('leaf', 'PL', 'PRIMARY_KEY_VALUE_LOC', None),
 'LOC_2': ('leaf', 'ST', 'LOCATION_DESCRIPTION', None),
 'LOC_3': ('leaf', 'IS', 'LOCATION_TYPE_LOC', None),
 'LOC_4': ('leaf', 'XON', 'ORGANIZATION_NAME_LOC', None),
 'LOC_5': ('leaf', 'XAD', 'LOCATION_ADDRESS', None),
 'LOC_6': ('leaf', 'XTN', 'LOCATION_PHONE', None),
 'LOC_7': ('leaf', 'CE', 'LICENSE_NUMBER', None),
 'LOC_8': ('leaf', 'IS', 'LOCATION_EQUIPMENT', None),
 'LRL_1': ('leaf', 'PL', 'PRIMARY_KEY_VALUE_LRL', None),
 'LRL_2': ('leaf', 'ID', 'SEGMENT_ACTION_CODE', None),
 'LRL_3': ('leaf', 'EI', 'SEGMENT_UNIQUE_KEY', None),
 'LRL_4': ('leaf', 'CE', 'LOCATION_RELATIONSHIP_ID', None),
 'LRL_5': ('leaf', 'XON', 'ORGANIZATIONAL_LOCATION_RELATIONSHIP_VALUE', None),
 'LRL_6': ('leaf', 'PL', 'PATIENT_LOCATION_RELATIONSHIP_VALUE', None),
 'MFA_1': ('leaf', 'ID', 'RECORD_LEVEL_EVENT_CODE', None),
 'MFA_2': ('leaf', 'ST', 'MFN_CONTROL_ID', None),
 'MFA_3': ('leaf', 'TS', 'EVENT_COMPLETION_DATE_TIME', None),
 'MFA_4': ('leaf', 'CE', 'MFN_RECORD_LEVEL_ERROR_RETURN', None),
 'MFA_5': ('leaf', 'CE', u'PRIMARY_KEY_VALUE_MFA', None),
 'MFA_6': ('leaf', 'ID', 'PRIMARY_KEY_VALUE_TYPE_MFA', None),
 'MFE_1': ('leaf', 'ID', 'RECORD_LEVEL_EVENT_CODE', None),
 'MFE_2': ('leaf', 'ST', 'MFN_CONTROL_ID', None),
 'MFE_3': ('leaf', 'TS', 'EFFECTIVE_DATE_TIME', None),
 'MFE_4': ('leaf', 'varies', 'PRIMARY_KEY_VALUE_MFE', None),
 'MFE_5': ('leaf', 'ID', 'PRIMARY_KEY_VALUE_TYPE', None),
 'MFI_1': ('leaf', 'CE', 'MASTER_FILE_IDENTIFIER', None),
 'MFI_2': ('leaf', 'HD', 'MASTER_FILE_APPLICATION_IDENTIFIER', None),
 'MFI_3': ('leaf', 'ID', 'FILE_LEVEL_EVENT_CODE', None),
 'MFI_4': ('leaf', 'TS', 'ENTERED_DATE_TIME', None),
 'MFI_5': ('leaf', 'TS', 'EFFECTIVE_DATE_TIME', None),
 'MFI_6': ('leaf', 'ID', 'RESPONSE_LEVEL_CODE', None),
 'MRG_1': ('leaf', 'CX', 'PRIOR_PATIENT_IDENTIFIER_LIST', None),
 'MRG_2': ('leaf', 'CX', 'PRIOR_ALTERNATE_PATIENT_ID', None),
 'MRG_3': ('leaf', 'CX', 'PRIOR_PATIENT_ACCOUNT_NUMBER', None),
 'MRG_4': ('leaf', 'CX', 'PRIOR_PATIENT_ID', None),
 'MRG_5': ('leaf', 'CX', 'PRIOR_VISIT_NUMBER', None),
 'MRG_6': ('leaf', 'CX', 'PRIOR_ALTERNATE_VISIT_ID', None),
 'MRG_7': ('leaf', 'XPN', 'PRIOR_PATIENT_NAME', None),
 'MSA_1': ('leaf', 'ID', 'ACKNOWLEDGEMENT_CODE', None),
 'MSA_2': ('leaf', 'ST', 'MESSAGE_CONTROL_ID', None),
 'MSA_3': ('leaf', 'ST', 'TEXT_MESSAGE', None),
 'MSA_4': ('leaf', 'NM', 'EXPECTED_SEQUENCE_NUMBER', None),
 'MSA_5': ('leaf', 'ID', 'DELAYED_ACKNOWLEDGMENT_TYPE', None),
 'MSA_6': ('leaf', 'CE', 'ERROR_CONDITION', None),
 'MSH_1': ('leaf', 'ST', 'FIELD_SEPARATOR', None),
 'MSH_10': ('leaf', 'ST', 'MESSAGE_CONTROL_ID', None),
 'MSH_11': ('leaf', 'PT', 'PROCESSING_ID', None),
 'MSH_12': ('leaf', 'VID', 'VERSION_ID', None),
 'MSH_13': ('leaf', 'NM', 'SEQUENCE_NUMBER', None),
 'MSH_14': ('leaf', 'ST', 'CONTINUATION_POINTER', None),
 'MSH_15': ('leaf', 'ID', 'ACCEPT_ACKNOWLEDGMENT_TYPE', None),
 'MSH_16': ('leaf', 'ID', 'APPLICATION_ACKNOWLEDGMENT_TYPE', None),
 'MSH_17': ('leaf', 'ID', 'COUNTRY_CODE', None),
 'MSH_18': ('leaf', 'ID', 'CHARACTER_SET', None),
 'MSH_19': ('leaf', 'CE', 'PRINCIPAL_LANGUAGE_OF_MESSAGE', None),
 'MSH_2': ('leaf', 'ST', 'ENCODING_CHARACTERS', None),
 'MSH_20': ('leaf', 'ID', 'ALTERNATE_CHARACTER_SET_HANDLING_SCHEME', None),
 'MSH_3': ('leaf', 'HD', 'SENDING_APPLICATION', None),
 'MSH_4': ('leaf', 'HD', 'SENDING_FACILITY', None),
 'MSH_5': ('leaf', 'HD', 'RECEIVING_APPLICATION', None),
 'MSH_6': ('leaf', 'HD', 'RECEIVING_FACILITY', None),
 'MSH_7': ('leaf', 'TS', 'DATE_TIME_OF_MESSAGE', None),
 'MSH_8': ('leaf', 'ST', 'SECURITY', None),
 'MSH_9': ('leaf', 'MSG', 'MESSAGE_TYPE', None),
 'NCK_1': ('leaf', 'TS', 'SYSTEM_DATE_TIME', None),
 'NK1_1': ('leaf', 'SI', 'SET_ID_NK1', None),
 'NK1_10': ('leaf', 'ST', 'NEXT_OF_KIN_ASSOCIATED_PARTIES_JOB_TITLE', None),
 'NK1_11': ('leaf',
            'JCC',
            'NEXT_OF_KIN_ASSOCIATED_PARTIES_JOB_CODE_CLASS',
            None),
 'NK1_12': ('leaf',
            'CX',
            'NEXT_OF_KIN_ASSOCIATED_PARTIES_EMPLOYEE_NUMBER',
            None),
 'NK1_13': ('leaf', 'XON', 'ORGANIZATION_NAME_NK1', None),
 'NK1_14': ('leaf', 'CE', 'MARITAL_STATUS', None),
 'NK1_15': ('leaf', 'IS', 'SEX', None),
 'NK1_16': ('leaf', 'TS', 'DATE_TIME_OF_BIRTH', None),
 'NK1_17': ('leaf', 'IS', 'LIVING_DEPENDENCY', None),
 'NK1_18': ('leaf', 'IS', 'AMBULATORY_STATUS', None),
 'NK1_19': ('leaf', 'CE', 'CITIZENSHIP', None),
 'NK1_2': ('leaf', 'XPN', 'NAME', None),
 'NK1_20': ('leaf', 'CE', 'PRIMARY_LANGUAGE', None),
 'NK1_21': ('leaf', 'IS', 'LIVING_ARRANGEMENT', None),
 'NK1_22': ('leaf', 'CE', 'PUBLICITY_CODE', None),
 'NK1_23': ('leaf', 'ID', 'PROTECTION_INDICATOR', None),
 'NK1_24': ('leaf', 'IS', 'STUDENT_INDICATOR', None),
 'NK1_25': ('leaf', 'CE', 'RELIGION', None),
 'NK1_26': ('leaf', 'XPN', u'MOTHER_S_MAIDEN_NAME', None),
 'NK1_27': ('leaf', 'CE', 'NATIONALITY', None),
 'NK1_28': ('leaf', 'CE', 'ETHNIC_GROUP', None),
 'NK1_29': ('leaf', 'CE', 'CONTACT_REASON', None),
 'NK1_3': ('leaf', 'CE', 'RELATIONSHIP', None),
 'NK1_30': ('leaf', 'XPN', u'CONTACT_PERSON_S_NAME', None),
 'NK1_31': ('leaf', 'XTN', u'CONTACT_PERSON_S_TELEPHONE_NUMBER', None),
 'NK1_32': ('leaf', 'XAD', u'CONTACT_PERSON_S_ADDRESS', None),
 'NK1_33': ('leaf', 'CX', u'NEXT_OF_KIN_ASSOCIATED_PARTY_S_IDENTIFIERS', None),
 'NK1_34': ('leaf', 'IS', 'JOB_STATUS', None),
 'NK1_35': ('leaf', 'CE', 'RACE', None),
 'NK1_36': ('leaf', 'IS', 'HANDICAP', None),
 'NK1_37': ('leaf', 'ST', 'CONTACT_PERSON_SOCIAL_SECURITY_NUMBER', None),
 'NK1_4': ('leaf', 'XAD', 'ADDRESS', None),
 'NK1_5': ('leaf', 'XTN', 'PHONE_NUMBER', None),
 'NK1_6': ('leaf', 'XTN', 'BUSINESS_PHONE_NUMBER', None),
 'NK1_7': ('leaf', 'CE', 'CONTACT_ROLE', None),
 'NK1_8': ('leaf', 'DT', 'START_DATE', None),
 'NK1_9': ('leaf', 'DT', 'END_DATE', None),
 'NPU_1': ('leaf', 'PL', 'BED_LOCATION', None),
 'NPU_2': ('leaf', 'IS', 'BED_STATUS', None),
 'NSC_1': ('leaf', 'IS', 'NETWORK_CHANGE_TYPE', None),
 'NSC_2': ('leaf', 'ST', 'CURRENT_CPU', None),
 'NSC_3': ('leaf', 'ST', 'CURRENT_FILESERVER', None),
 'NSC_4': ('leaf', 'ST', 'CURRENT_APPLICATION', None),
 'NSC_5': ('leaf', 'ST', 'CURRENT_FACILITY', None),
 'NSC_6': ('leaf', 'ST', 'NEW_CPU', None),
 'NSC_7': ('leaf', 'ST', 'NEW_FILESERVER', None),
 'NSC_8': ('leaf', 'ST', 'NEW_APPLICATION', None),
 'NSC_9': ('leaf', 'ST', 'NEW_FACILITY', None),
 'NST_1': ('leaf', 'ID', 'STATISTICS_AVAILABLE', None),
 'NST_10': ('leaf', 'NM', 'CHECKSUM_ERRORS_RECEIVED', None),
 'NST_11': ('leaf', 'NM', 'LENGTH_ERRORS_RECEIVED', None),
 'NST_12': ('leaf', 'NM', 'OTHER_ERRORS_RECEIVED', None),
 'NST_13': ('leaf', 'NM', 'CONNECT_TIMEOUTS', None),
 'NST_14': ('leaf', 'NM', 'RECEIVE_TIMEOUTS', None),
 'NST_15': ('leaf', 'NM', 'NETWORK_ERRORS', None),
 'NST_2': ('leaf', 'ST', 'SOURCE_IDENTIFIER', None),
 'NST_3': ('leaf', 'ID', 'SOURCE_TYPE', None),
 'NST_4': ('leaf', 'TS', 'STATISTICS_START', None),
 'NST_5': ('leaf', 'TS', 'STATISTICS_END', None),
 'NST_6': ('leaf', 'NM', 'RECEIVE_CHARACTER_COUNT', None),
 'NST_7': ('leaf', 'NM', 'SEND_CHARACTER_COUNT', None),
 'NST_8': ('leaf', 'NM', 'MESSAGES_RECEIVED', None),
 'NST_9': ('leaf', 'NM', 'MESSAGES_SENT', None),
 'NTE_1': ('leaf', 'SI', 'SET_ID_NTE', None),
 'NTE_2': ('leaf', 'ID', 'SOURCE_OF_COMMENT', None),
 'NTE_3': ('leaf', 'FT', 'COMMENT', None),
 'NTE_4': ('leaf', 'CE', 'COMMENT_TYPE', None),
 'OBR_1': ('leaf', 'SI', 'SET_ID_OBR', None),
 'OBR_10': ('leaf', 'XCN', 'COLLECTOR_IDENTIFIER_', None),
 'OBR_11': ('leaf', 'ID', 'SPECIMEN_ACTION_CODE_', None),
 'OBR_12': ('leaf', 'CE', 'DANGER_CODE', None),
 'OBR_13': ('leaf', 'ST', 'RELEVANT_CLINICAL_INFO_', None),
 'OBR_14': ('leaf', 'TS', 'SPECIMEN_RECEIVED_DATE_TIME_', None),
 'OBR_15': ('leaf', 'SPS', 'SPECIMEN_SOURCE', None),
 'OBR_16': ('leaf', 'XCN', 'ORDERING_PROVIDER', None),
 'OBR_17': ('leaf', 'XTN', 'ORDER_CALLBACK_PHONE_NUMBER', None),
 'OBR_18': ('leaf', 'ST', 'PLACER_FIELD_1', None),
 'OBR_19': ('leaf', 'ST', 'PLACER_FIELD_2', None),
 'OBR_2': ('leaf', 'EI', 'PLACER_ORDER_NUMBER', None),
 'OBR_20': ('leaf', 'ST', 'FILLER_FIELD_1_', None),
 'OBR_21': ('leaf', 'ST', 'FILLER_FIELD_2_', None),
 'OBR_22': ('leaf', 'TS', 'RESULTS_RPT_STATUS_CHNG_DATE_TIME_', None),
 'OBR_23': ('leaf', 'MOC', 'CHARGE_TO_PRACTICE_', None),
 'OBR_24': ('leaf', 'ID', 'DIAGNOSTIC_SERV_SECT_ID', None),
 'OBR_25': ('leaf', 'ID', 'RESULT_STATUS_', None),
 'OBR_26': ('leaf', 'PRL', 'PARENT_RESULT_', None),
 'OBR_27': ('leaf', 'TQ', 'QUANTITY_TIMING', None),
 'OBR_28': ('leaf', 'XCN', 'RESULT_COPIES_TO', None),
 'OBR_29': ('leaf', 'EIP', 'PARENT', None),
 'OBR_3': ('leaf', 'EI', 'FILLER_ORDER_NUMBER', None),
 'OBR_30': ('leaf', 'ID', 'TRANSPORTATION_MODE', None),
 'OBR_31': ('leaf', 'CE', 'REASON_FOR_STUDY', None),
 'OBR_32': ('leaf', 'NDL', 'PRINCIPAL_RESULT_INTERPRETER_', None),
 'OBR_33': ('leaf', 'NDL', 'ASSISTANT_RESULT_INTERPRETER_', None),
 'OBR_34': ('leaf', 'NDL', 'TECHNICIAN_', None),
 'OBR_35': ('leaf', 'NDL', 'TRANSCRIPTIONIST_', None),
 'OBR_36': ('leaf', 'TS', 'SCHEDULED_DATE_TIME_', None),
 'OBR_37': ('leaf', 'NM', 'NUMBER_OF_SAMPLE_CONTAINERS_', None),
 'OBR_38': ('leaf', 'CE', 'TRANSPORT_LOGISTICS_OF_COLLECTED_SAMPLE_', None),
 'OBR_39': ('leaf', 'CE', u'COLLECTOR_S_COMMENT_', None),
 'OBR_4': ('leaf', 'CE', 'UNIVERSAL_SERVICE_ID', None),
 'OBR_40': ('leaf', 'CE', 'TRANSPORT_ARRANGEMENT_RESPONSIBILITY', None),
 'OBR_41': ('leaf', 'ID', 'TRANSPORT_ARRANGED', None),
 'OBR_42': ('leaf', 'ID', 'ESCORT_REQUIRED', None),
 'OBR_43': ('leaf', 'CE', 'PLANNED_PATIENT_TRANSPORT_COMMENT', None),
 'OBR_44': ('leaf', 'CE', 'PROCEDURE_CODE', None),
 'OBR_45': ('leaf', 'CE', 'PROCEDURE_CODE_MODIFIER', None),
 'OBR_5': ('leaf', 'ID', 'PRIORITY_OBR', None),
 'OBR_6': ('leaf', 'TS', 'REQUESTED_DATE_TIME', None),
 'OBR_7': ('leaf', 'TS', 'OBSERVATION_DATE_TIME_', None),
 'OBR_8': ('leaf', 'TS', 'OBSERVATION_END_DATE_TIME_', None),
 'OBR_9': ('leaf', 'CQ', 'COLLECTION_VOLUME_', None),
 'OBX_1': ('leaf', 'SI', 'SET_ID_OBX', None),
 'OBX_10': ('leaf', 'ID', 'NATURE_OF_ABNORMAL_TEST', None),
 'OBX_11': ('leaf', 'ID', 'OBSERVATION_RESULT_STATUS', None),
 'OBX_12': ('leaf', 'TS', 'DATE_LAST_OBS_NORMAL_VALUES', None),
 'OBX_13': ('leaf', 'ST', 'USER_DEFINED_ACCESS_CHECKS', None),
 'OBX_14': ('leaf', 'TS', 'DATE_TIME_OF_THE_OBSERVATION', None),
 'OBX_15': ('leaf', 'CE', 'PRODUCER_S_ID', None),
 'OBX_16': ('leaf', 'XCN', 'RESPONSIBLE_OBSERVER', None),
 'OBX_17': ('leaf', 'CE', 'OBSERVATION_METHOD', None),
 'OBX_2': ('leaf', 'ID', 'VALUE_TYPE', None),
 'OBX_3': ('leaf', 'CE', 'OBSERVATION_IDENTIFIER', None),
 'OBX_4': ('leaf', 'ST', 'OBSERVATION_SUB_ID', None),
 'OBX_5': ('leaf', 'varies', 'OBSERVATION_VALUE', None),
 'OBX_6': ('leaf', 'CE', 'UNITS', None),
 'OBX_7': ('leaf', 'ST', 'REFERENCES_RANGE', None),
 'OBX_8': ('leaf', 'ID', 'ABNORMAL_FLAGS', None),
 'OBX_9': ('leaf', 'NM', 'PROBABILITY', None),
 'ODS_1': ('leaf', 'ID', 'TYPE', None),
 'ODS_2': ('leaf', 'CE', 'SERVICE_PERIOD', None),
 'ODS_3': ('leaf', 'CE', 'DIET_SUPPLEMENT_OR_PREFERENCE_CODE', None),
 'ODS_4': ('leaf', 'ST', 'TEXT_INSTRUCTION', None),
 'ODT_1': ('leaf', 'CE', 'TRAY_TYPE', None),
 'ODT_2': ('leaf', 'CE', 'SERVICE_PERIOD', None),
 'ODT_3': ('leaf', 'ST', 'TEXT_INSTRUCTION', None),
 'OM1_1': ('leaf', 'NM', 'SEQUENCE_NUMBER_TEST_OBSERVATION_MASTER_FILE', None),
 'OM1_10': ('leaf',
            'ST',
            'PREFERRED_SHORT_NAME_OR_MNEMONIC_FOR_OBSERVATION',
            None),
 'OM1_11': ('leaf', 'ST', 'PREFERRED_LONG_NAME_FOR_THE_OBSERVATION', None),
 'OM1_12': ('leaf', 'ID', 'ORDERABILITY', None),
 'OM1_13': ('leaf',
            'CE',
            'IDENTITY_OF_INSTRUMENT_USED_TO_PERFORM_THIS_STUDY',
            None),
 'OM1_14': ('leaf', 'CE', 'CODED_REPRESENTATION_OF_METHOD', None),
 'OM1_15': ('leaf', 'ID', 'PORTABLE', None),
 'OM1_16': ('leaf', 'CE', 'OBSERVATION_PRODUCING_DEPARTMENT_SECTION', None),
 'OM1_17': ('leaf', 'XTN', 'TELEPHONE_NUMBER_OF_SECTION', None),
 'OM1_18': ('leaf', 'IS', 'NATURE_OF_TEST_OBSERVATION', None),
 'OM1_19': ('leaf', 'CE', 'REPORT_SUBHEADER', None),
 'OM1_2': ('leaf', 'CE', 'PRODUCER_S_TEST_OBSERVATION_ID', None),
 'OM1_20': ('leaf', 'ST', 'REPORT_DISPLAY_ORDER', None),
 'OM1_21': ('leaf',
            'TS',
            'DATE_TIME_STAMP_FOR_ANY_CHANGE_IN_DEFINITION_FOR_THE_OBSERVATION',
            None),
 'OM1_22': ('leaf', 'TS', 'EFFECTIVE_DATE_TIME_OF_CHANGE', None),
 'OM1_23': ('leaf', 'NM', 'TYPICAL_TURN_AROUND_TIME', None),
 'OM1_24': ('leaf', 'NM', 'PROCESSING_TIME', None),
 'OM1_25': ('leaf', 'ID', 'PROCESSING_PRIORITY', None),
 'OM1_26': ('leaf', 'ID', 'REPORTING_PRIORITY', None),
 'OM1_27': ('leaf',
            'CE',
            'OUTSIDE_SITE_S_WHERE_OBSERVATION_MAY_BE_PERFORMED',
            None),
 'OM1_28': ('leaf', 'XAD', 'ADDRESS_OF_OUTSIDE_SITE_S_', None),
 'OM1_29': ('leaf', 'XTN', 'PHONE_NUMBER_OF_OUTSIDE_SITE', None),
 'OM1_3': ('leaf', 'ID', 'PERMITTED_DATA_TYPES', None),
 'OM1_30': ('leaf', 'IS', 'CONFIDENTIALITY_CODE', None),
 'OM1_31': ('leaf', 'CE', 'OBSERVATIONS_REQUIRED_TO_INTERPRET_THE_OBS', None),
 'OM1_32': ('leaf', 'TX', 'INTERPRETATION_OF_OBSERVATIONS', None),
 'OM1_33': ('leaf', 'CE', 'CONTRAINDICATIONS_TO_OBSERVATIONS', None),
 'OM1_34': ('leaf', 'CE', 'REFLEX_TESTS_OBSERVATIONS', None),
 'OM1_35': ('leaf', 'TX', 'RULES_THAT_TRIGGER_REFLEX_TESTING', None),
 'OM1_36': ('leaf', 'CE', 'FIXED_CANNED_MESSAGE', None),
 'OM1_37': ('leaf', 'TX', 'PATIENT_PREPARATION', None),
 'OM1_38': ('leaf', 'CE', 'PROCEDURE_MEDICATION', None),
 'OM1_39': ('leaf', 'TX', 'FACTORS_THAT_MAY_EFFECT_THE_OBSERVATION', None),
 'OM1_4': ('leaf', 'ID', 'SPECIMEN_REQUIRED', None),
 'OM1_40': ('leaf', 'ST', 'TEST_OBSERVATION_PERFORMANCE_SCHEDULE', None),
 'OM1_41': ('leaf', 'TX', 'DESCRIPTION_OF_TEST_METHODS', None),
 'OM1_42': ('leaf', 'CE', 'KIND_OF_QUANTITY_OBSERVED', None),
 'OM1_43': ('leaf', 'CE', 'POINT_VERSUS_INTERVAL', None),
 'OM1_44': ('leaf', 'TX', 'CHALLENGE_INFORMATION', None),
 'OM1_45': ('leaf', 'CE', 'RELATIONSHIP_MODIFIER', None),
 'OM1_46': ('leaf', 'CE', 'TARGET_ANATOMIC_SITE_OF_TEST', None),
 'OM1_47': ('leaf', 'CE', 'MODALITY_OF_IMAGING_MEASUREMENT', None),
 'OM1_5': ('leaf', 'CE', 'PRODUCER_ID', None),
 'OM1_6': ('leaf', 'TX', 'OBSERVATION_DESCRIPTION', None),
 'OM1_7': ('leaf',
           'CE',
           'OTHER_TEST_OBSERVATION_IDS_FOR_THE_OBSERVATION',
           None),
 'OM1_8': ('leaf', 'ST', 'OTHER_NAMES', None),
 'OM1_9': ('leaf', 'ST', 'PREFERRED_REPORT_NAME_FOR_THE_OBSERVATION', None),
 'OM2_1': ('leaf', 'NM', 'SEQUENCE_NUMBER_TEST_OBSERVATION_MASTER_FILE', None),
 'OM2_10': ('leaf', 'NM', 'MINIMUM_MEANINGFUL_INCREMENTS', None),
 'OM2_2': ('leaf', 'CE', 'UNITS_OF_MEASURE', None),
 'OM2_3': ('leaf', 'NM', 'RANGE_OF_DECIMAL_PRECISION', None),
 'OM2_4': ('leaf', 'CE', 'CORRESPONDING_SI_UNITS_OF_MEASURE', None),
 'OM2_5': ('leaf', 'TX', 'SI_CONVERSION_FACTOR', None),
 'OM2_6': ('leaf',
           'RFR',
           'REFERENCE_NORMAL_RANGE_ORDINAL_CONTINUOUS_OBS',
           None),
 'OM2_7': ('leaf', 'NR', 'CRITICAL_RANGE_FOR_ORDINAL_CONTINUOUS_OBS', None),
 'OM2_8': ('leaf', 'RFR', 'ABSOLUTE_RANGE_FOR_ORDINAL_CONTINUOUS_OBS', None),
 'OM2_9': ('leaf', 'DLT', 'DELTA_CHECK_CRITERIA', None),
 'OM3_1': ('leaf', 'NM', 'SEQUENCE_NUMBER_TEST_OBSERVATION_MASTER_FILE', None),
 'OM3_2': ('leaf', 'CE', 'PREFERRED_CODING_SYSTEM', None),
 'OM3_3': ('leaf', 'CE', u'VALID_CODED_ANSWERS_', None),
 'OM3_4': ('leaf',
           'CE',
           'NORMAL_TEXT_CODES_FOR_CATEGORICAL_OBSERVATIONS',
           None),
 'OM3_5': ('leaf',
           'CE',
           'ABNORMAL_TEXT_CODES_FOR_CATEGORICAL_OBSERVATIONS',
           None),
 'OM3_6': ('leaf',
           'CE',
           'CRITICAL_TEXT_CODES_FOR_CATEGORICAL_OBSERVATIONS',
           None),
 'OM3_7': ('leaf', 'ID', 'VALUE_TYPE', None),
 'OM4_1': ('leaf', 'NM', 'SEQUENCE_NUMBER_TEST_OBSERVATION_MASTER_FILE', None),
 'OM4_10': ('leaf', 'CQ', 'NORMAL_COLLECTION_VOLUME', None),
 'OM4_11': ('leaf', 'CQ', 'MINIMUM_COLLECTION_VOLUME', None),
 'OM4_12': ('leaf', 'TX', 'SPECIMEN_REQUIREMENTS', None),
 'OM4_13': ('leaf', 'ID', 'SPECIMEN_PRIORITIES', None),
 'OM4_14': ('leaf', 'CQ', 'SPECIMEN_RETENTION_TIME', None),
 'OM4_2': ('leaf', 'ID', 'DERIVED_SPECIMEN', None),
 'OM4_3': ('leaf', 'TX', 'CONTAINER_DESCRIPTION', None),
 'OM4_4': ('leaf', 'NM', 'CONTAINER_VOLUME', None),
 'OM4_5': ('leaf', 'CE', 'CONTAINER_UNITS', None),
 'OM4_6': ('leaf', 'CE', 'SPECIMEN', None),
 'OM4_7': ('leaf', 'CE', 'ADDITIVE', None),
 'OM4_8': ('leaf', 'TX', 'PREPARATION', None),
 'OM4_9': ('leaf', 'TX', 'SPECIAL_HANDLING_REQUIREMENTS', None),
 'OM5_1': ('leaf', 'NM', 'SEQUENCE_NUMBER_TEST_OBSERVATION_MASTER_FILE', None),
 'OM5_2': ('leaf',
           'CE',
           'TEST_OBSERVATIONS_INCLUDED_WITHIN_AN_ORDERED_TEST_BATTERY',
           None),
 'OM5_3': ('leaf', 'ST', 'OBSERVATION_ID_SUFFIXES', None),
 'OM6_1': ('leaf', 'NM', 'SEQUENCE_NUMBER_TEST_OBSERVATION_MASTER_FILE', None),
 'OM6_2': ('leaf', 'TX', 'DERIVATION_RULE', None),
 'ORC_1': ('leaf', 'ID', 'ORDER_CONTROL', None),
 'ORC_10': ('leaf', 'XCN', 'ENTERED_BY', None),
 'ORC_11': ('leaf', 'XCN', 'VERIFIED_BY', None),
 'ORC_12': ('leaf', 'XCN', 'ORDERING_PROVIDER', None),
 'ORC_13': ('leaf', 'PL', u'ENTERER_S_LOCATION', None),
 'ORC_14': ('leaf', 'XTN', 'CALL_BACK_PHONE_NUMBER', None),
 'ORC_15': ('leaf', 'TS', 'ORDER_EFFECTIVE_DATE_TIME', None),
 'ORC_16': ('leaf', 'CE', 'ORDER_CONTROL_CODE_REASON', None),
 'ORC_17': ('leaf', 'CE', 'ENTERING_ORGANIZATION', None),
 'ORC_18': ('leaf', 'CE', 'ENTERING_DEVICE', None),
 'ORC_19': ('leaf', 'XCN', 'ACTION_BY', None),
 'ORC_2': ('leaf', 'EI', 'PLACER_ORDER_NUMBER', None),
 'ORC_20': ('leaf', 'CE', 'ADVANCED_BENEFICIARY_NOTICE_CODE', None),
 'ORC_21': ('leaf', 'XON', 'ORDERING_FACILITY_NAME', None),
 'ORC_22': ('leaf', 'XAD', 'ORDERING_FACILITY_ADDRESS', None),
 'ORC_23': ('leaf', 'XTN', 'ORDERING_FACILITY_PHONE_NUMBER', None),
 'ORC_24': ('leaf', 'XAD', 'ORDERING_PROVIDER_ADDRESS', None),
 'ORC_3': ('leaf', 'EI', 'FILLER_ORDER_NUMBER', None),
 'ORC_4': ('leaf', 'EI', 'PLACER_GROUP_NUMBER', None),
 'ORC_5': ('leaf', 'ID', 'ORDER_STATUS', None),
 'ORC_6': ('leaf', 'ID', 'RESPONSE_FLAG', None),
 'ORC_7': ('leaf', 'TQ', 'QUANTITY_TIMING', None),
 'ORC_8': ('leaf', 'EIP', 'PARENT', None),
 'ORC_9': ('leaf', 'TS', 'DATE_TIME_OF_TRANSACTION', None),
 'PCR_1': ('leaf', 'CE', 'IMPLICATED_PRODUCT', None),
 'PCR_10': ('leaf', 'CE', 'INDICATION_FOR_PRODUCT_USE', None),
 'PCR_11': ('leaf', 'IS', 'PRODUCT_PROBLEM', None),
 'PCR_12': ('leaf', 'ST', 'PRODUCT_SERIAL_LOT_NUMBER', None),
 'PCR_13': ('leaf', 'IS', 'PRODUCT_AVAILABLE_FOR_INSPECTION', None),
 'PCR_14': ('leaf', 'CE', 'PRODUCT_EVALUATION_PERFORMED', None),
 'PCR_15': ('leaf', 'CE', 'PRODUCT_EVALUATION_STATUS', None),
 'PCR_16': ('leaf', 'CE', 'PRODUCT_EVALUATION_RESULTS', None),
 'PCR_17': ('leaf', 'ID', 'EVALUATED_PRODUCT_SOURCE', None),
 'PCR_18': ('leaf', 'TS', 'DATE_PRODUCT_RETURNED_TO_MANUFACTURER', None),
 'PCR_19': ('leaf', 'ID', 'DEVICE_OPERATOR_QUALIFICATIONS', None),
 'PCR_2': ('leaf', 'IS', 'GENERIC_PRODUCT', None),
 'PCR_20': ('leaf', 'ID', 'RELATEDNESS_ASSESSMENT', None),
 'PCR_21': ('leaf', 'ID', 'ACTION_TAKEN_IN_RESPONSE_TO_THE_EVENT', None),
 'PCR_22': ('leaf', 'ID', 'EVENT_CAUSALITY_OBSERVATIONS', None),
 'PCR_23': ('leaf', 'ID', 'INDIRECT_EXPOSURE_MECHANISM', None),
 'PCR_3': ('leaf', 'CE', 'PRODUCT_CLASS', None),
 'PCR_4': ('leaf', 'CQ', 'TOTAL_DURATION_OF_THERAPY', None),
 'PCR_5': ('leaf', 'TS', 'PRODUCT_MANUFACTURE_DATE', None),
 'PCR_6': ('leaf', 'TS', 'PRODUCT_EXPIRATION_DATE', None),
 'PCR_7': ('leaf', 'TS', 'PRODUCT_IMPLANTATION_DATE', None),
 'PCR_8': ('leaf', 'TS', 'PRODUCT_EXPLANTATION_DATE', None),
 'PCR_9': ('leaf', 'IS', 'SINGLE_USE_DEVICE', None),
 'PD1_1': ('leaf', 'IS', 'LIVING_DEPENDENCY', None),
 'PD1_10': ('leaf', 'CX', 'DUPLICATE_PATIENT', None),
 'PD1_11': ('leaf', 'CE', 'PUBLICITY_CODE', None),
 'PD1_12': ('leaf', 'ID', 'PROTECTION_INDICATOR', None),
 'PD1_2': ('leaf', 'IS', 'LIVING_ARRANGEMENT', None),
 'PD1_3': ('leaf', 'XON', 'PATIENT_PRIMARY_FACILITY', None),
 'PD1_4': ('leaf', 'XCN', 'PATIENT_PRIMARY_CARE_PROVIDER_NAME_ID_NO_', None),
 'PD1_5': ('leaf', 'IS', 'STUDENT_INDICATOR', None),
 'PD1_6': ('leaf', 'IS', 'HANDICAP', None),
 'PD1_7': ('leaf', 'IS', 'LIVING_WILL', None),
 'PD1_8': ('leaf', 'IS', 'ORGAN_DONOR', None),
 'PD1_9': ('leaf', 'ID', 'SEPARATE_BILL', None),
 'PDC_1': ('leaf', 'XON', 'MANUFACTURER_DISTRIBUTOR', None),
 'PDC_10': ('leaf', 'ID', 'MARKETING_BASIS', None),
 'PDC_11': ('leaf', 'ST', 'MARKETING_APPROVAL_ID', None),
 'PDC_12': ('leaf', 'CQ', 'LABELED_SHELF_LIFE', None),
 'PDC_13': ('leaf', 'CQ', 'EXPECTED_SHELF_LIFE', None),
 'PDC_14': ('leaf', 'TS', 'DATE_FIRST_MARKETED', None),
 'PDC_15': ('leaf', 'TS', 'DATE_LAST_MARKETED', None),
 'PDC_2': ('leaf', 'CE', 'COUNTRY', None),
 'PDC_3': ('leaf', 'ST', 'BRAND_NAME', None),
 'PDC_4': ('leaf', 'ST', 'DEVICE_FAMILY_NAME', None),
 'PDC_5': ('leaf', 'CE', 'GENERIC_NAME', None),
 'PDC_6': ('leaf', 'ST', 'MODEL_IDENTIFIER', None),
 'PDC_7': ('leaf', 'ST', 'CATALOGUE_IDENTIFIER', None),
 'PDC_8': ('leaf', 'ST', 'OTHER_IDENTIFIER', None),
 'PDC_9': ('leaf', 'CE', 'PRODUCT_CODE', None),
 'PEO_1': ('leaf', 'CE', 'EVENT_IDENTIFIERS_USED', None),
 'PEO_10': ('leaf', 'ID', 'EVENT_EXPECTED', None),
 'PEO_11': ('leaf', 'ID', 'EVENT_OUTCOME', None),
 'PEO_12': ('leaf', 'ID', 'PATIENT_OUTCOME', None),
 'PEO_13': ('leaf', 'FT', 'EVENT_DESCRIPTION_FROM_OTHERS', None),
 'PEO_14': ('leaf', 'FT', 'EVENT_FROM_ORIGINAL_REPORTER', None),
 'PEO_15': ('leaf', 'FT', 'EVENT_DESCRIPTION_FROM_PATIENT', None),
 'PEO_16': ('leaf', 'FT', 'EVENT_DESCRIPTION_FROM_PRACTITIONER', None),
 'PEO_17': ('leaf', 'FT', 'EVENT_DESCRIPTION_FROM_AUTOPSY', None),
 'PEO_18': ('leaf', 'CE', 'CAUSE_OF_DEATH', None),
 'PEO_19': ('leaf', 'XPN', 'PRIMARY_OBSERVER_NAME', None),
 'PEO_2': ('leaf', 'CE', 'EVENT_SYMPTOM_DIAGNOSIS_CODE', None),
 'PEO_20': ('leaf', 'XAD', 'PRIMARY_OBSERVER_ADDRESS', None),
 'PEO_21': ('leaf', 'XTN', 'PRIMARY_OBSERVER_TELEPHONE', None),
 'PEO_22': ('leaf', 'ID', u'PRIMARY_OBSERVER_S_QUALIFICATION', None),
 'PEO_23': ('leaf', 'ID', 'CONFIRMATION_PROVIDED_BY', None),
 'PEO_24': ('leaf', 'TS', 'PRIMARY_OBSERVER_AWARE_DATE_TIME', None),
 'PEO_25': ('leaf',
            'ID',
            u'PRIMARY_OBSERVER_S_IDENTITY_MAY_BE_DIVULGED',
            None),
 'PEO_3': ('leaf', 'TS', 'EVENT_ONSET_DATE_TIME', None),
 'PEO_4': ('leaf', 'TS', 'EVENT_EXACERBATION_DATE_TIME', None),
 'PEO_5': ('leaf', 'TS', 'EVENT_IMPROVED_DATE_TIME', None),
 'PEO_6': ('leaf', 'TS', 'EVENT_ENDED_DATA_TIME', None),
 'PEO_7': ('leaf', 'XAD', 'EVENT_LOCATION_OCCURRED_ADDRESS', None),
 'PEO_8': ('leaf', 'ID', 'EVENT_QUALIFICATION', None),
 'PEO_9': ('leaf', 'ID', 'EVENT_SERIOUS', None),
 'PES_1': ('leaf', 'XON', 'SENDER_ORGANIZATION_NAME', None),
 'PES_10': ('leaf', 'TS', 'EVENT_REPORT_DATE', None),
 'PES_11': ('leaf', 'ID', 'EVENT_REPORT_TIMING_TYPE', None),
 'PES_12': ('leaf', 'ID', 'EVENT_REPORT_SOURCE', None),
 'PES_13': ('leaf', 'ID', 'EVENT_REPORTED_TO', None),
 'PES_2': ('leaf', 'XCN', 'SENDER_INDIVIDUAL_NAME', None),
 'PES_3': ('leaf', 'XAD', 'SENDER_ADDRESS', None),
 'PES_4': ('leaf', 'XTN', 'SENDER_TELEPHONE', None),
 'PES_5': ('leaf', 'EI', 'SENDER_EVENT_IDENTIFIER', None),
 'PES_6': ('leaf', 'NM', 'SENDER_SEQUENCE_NUMBER', None),
 'PES_7': ('leaf', 'FT', 'SENDER_EVENT_DESCRIPTION', None),
 'PES_8': ('leaf', 'FT', 'SENDER_COMMENT', None),
 'PES_9': ('leaf', 'TS', 'SENDER_AWARE_DATE_TIME', None),
 'PID_1': ('leaf', 'SI', 'SET_ID_PID', None),
 'PID_10': ('leaf', 'CE', 'RACE', None),
 'PID_11': ('leaf', 'XAD', 'PATIENT_ADDRESS', None),
 'PID_12': ('leaf', 'IS', 'COUNTY_CODE', None),
 'PID_13': ('leaf', 'XTN', 'PHONE_NUMBER_HOME', None),
 'PID_14': ('leaf', 'XTN', 'PHONE_NUMBER_BUSINESS', None),
 'PID_15': ('leaf', 'CE', 'PRIMARY_LANGUAGE', None),
 'PID_16': ('leaf', 'CE', 'MARITAL_STATUS', None),
 'PID_17': ('leaf', 'CE', 'RELIGION', None),
 'PID_18': ('leaf', 'CX', 'PATIENT_ACCOUNT_NUMBER', None),
 'PID_19': ('leaf', 'ST', 'SSN_NUMBER_PATIENT', None),
 'PID_2': ('leaf', 'CX', 'PATIENT_ID', None),
 'PID_20': ('leaf', 'DLN', 'DRIVER_S_LICENSE_NUMBER_PATIENT', None),
 'PID_21': ('leaf', 'CX', 'MOTHER_S_IDENTIFIER', None),
 'PID_22': ('leaf', 'CE', 'ETHNIC_GROUP', None),
 'PID_23': ('leaf', 'ST', 'BIRTH_PLACE', None),
 'PID_24': ('leaf', 'ID', 'MULTIPLE_BIRTH_INDICATOR', None),
 'PID_25': ('leaf', 'NM', 'BIRTH_ORDER', None),
 'PID_26': ('leaf', 'CE', 'CITIZENSHIP', None),
 'PID_27': ('leaf', 'CE', 'VETERANS_MILITARY_STATUS', None),
 'PID_28': ('leaf', 'CE', 'NATIONALITY', None),
 'PID_29': ('leaf', 'TS', 'PATIENT_DEATH_DATE_AND_TIME', None),
 'PID_3': ('leaf', 'CX', 'PATIENT_IDENTIFIER_LIST', None),
 'PID_30': ('leaf', 'ID', 'PATIENT_DEATH_INDICATOR', None),
 'PID_4': ('leaf', 'CX', 'ALTERNATE_PATIENT_ID_PID', None),
 'PID_5': ('leaf', 'XPN', 'PATIENT_NAME', None),
 'PID_6': ('leaf', 'XPN', u'MOTHER_S_MAIDEN_NAME', None),
 'PID_7': ('leaf', 'TS', 'DATE_TIME_OF_BIRTH', None),
 'PID_8': ('leaf', 'IS', 'SEX', None),
 'PID_9': ('leaf', 'XPN', 'PATIENT_ALIAS', None),
 'PR1_1': ('leaf', 'SI', 'SET_ID_PR1', None),
 'PR1_10': ('leaf', 'NM', 'ANESTHESIA_MINUTES', None),
 'PR1_11': ('leaf', 'XCN', 'SURGEON', None),
 'PR1_12': ('leaf', 'XCN', 'PROCEDURE_PRACTITIONER', None),
 'PR1_13': ('leaf', 'CE', 'CONSENT_CODE', None),
 'PR1_14': ('leaf', 'NM', 'PROCEDURE_PRIORITY', None),
 'PR1_15': ('leaf', 'CE', 'ASSOCIATED_DIAGNOSIS_CODE', None),
 'PR1_16': ('leaf', 'CE', 'PROCEDURE_CODE_MODIFIER', None),
 'PR1_2': ('leaf', 'IS', 'PROCEDURE_CODING_METHOD', None),
 'PR1_3': ('leaf', 'CE', 'PROCEDURE_CODE', None),
 'PR1_4': ('leaf', 'ST', 'PROCEDURE_DESCRIPTION', None),
 'PR1_5': ('leaf', 'TS', 'PROCEDURE_DATE_TIME', None),
 'PR1_6': ('leaf', 'IS', 'PROCEDURE_FUNCTIONAL_TYPE', None),
 'PR1_7': ('leaf', 'NM', 'PROCEDURE_MINUTES', None),
 'PR1_8': ('leaf', 'XCN', 'ANESTHESIOLOGIST', None),
 'PR1_9': ('leaf', 'IS', 'ANESTHESIA_CODE', None),
 'PRA_1': ('leaf', 'CE', 'PRIMARY_KEY_VALUE_PRA', None),
 'PRA_2': ('leaf', 'CE', 'PRACTITIONER_GROUP', None),
 'PRA_3': ('leaf', 'IS', 'PRACTITIONER_CATEGORY', None),
 'PRA_4': ('leaf', 'ID', 'PROVIDER_BILLING', None),
 'PRA_5': ('leaf', 'SPD', 'SPECIALTY', None),
 'PRA_6': ('leaf', 'PLN', 'PRACTITIONER_ID_NUMBERS', None),
 'PRA_7': ('leaf', 'PIP', 'PRIVILEGES', None),
 'PRA_8': ('leaf', 'DT', 'DATE_ENTERED_PRACTICE', None),
 'PRB_1': ('leaf', 'ID', 'ACTION_CODE', None),
 'PRB_10': ('leaf', 'CE', 'PROBLEM_CLASSIFICATION', None),
 'PRB_11': ('leaf', 'CE', 'PROBLEM_MANAGEMENT_DISCIPLINE', None),
 'PRB_12': ('leaf', 'CE', 'PROBLEM_PERSISTENCE', None),
 'PRB_13': ('leaf', 'CE', 'PROBLEM_CONFIRMATION_STATUS', None),
 'PRB_14': ('leaf', 'CE', 'PROBLEM_LIFE_CYCLE_STATUS', None),
 'PRB_15': ('leaf', 'TS', 'PROBLEM_LIFE_CYCLE_STATUS_DATE_TIME', None),
 'PRB_16': ('leaf', 'TS', 'PROBLEM_DATE_OF_ONSET', None),
 'PRB_17': ('leaf', 'ST', 'PROBLEM_ONSET_TEXT', None),
 'PRB_18': ('leaf', 'CE', 'PROBLEM_RANKING', None),
 'PRB_19': ('leaf', 'CE', 'CERTAINTY_OF_PROBLEM', None),
 'PRB_2': ('leaf', 'TS', 'ACTION_DATE_TIME', None),
 'PRB_20': ('leaf', 'NM', 'PROBABILITY_OF_PROBLEM_0_1_', None),
 'PRB_21': ('leaf', 'CE', 'INDIVIDUAL_AWARENESS_OF_PROBLEM', None),
 'PRB_22': ('leaf', 'CE', 'PROBLEM_PROGNOSIS', None),
 'PRB_23': ('leaf', 'CE', 'INDIVIDUAL_AWARENESS_OF_PROGNOSIS', None),
 'PRB_24': ('leaf',
            'ST',
            'FAMILY_SIGNIFICANT_OTHER_AWARENESS_OF_PROBLEM_PROGNOSIS',
            None),
 'PRB_25': ('leaf', 'CE', 'SECURITY_SENSITIVITY', None),
 'PRB_3': ('leaf', 'CE', 'PROBLEM_ID', None),
 'PRB_4': ('leaf', 'EI', 'PROBLEM_INSTANCE_ID', None),
 'PRB_5': ('leaf', 'EI', 'EPISODE_OF_CARE_ID', None),
 'PRB_6': ('leaf', 'NM', 'PROBLEM_LIST_PRIORITY', None),
 'PRB_7': ('leaf', 'TS', 'PROBLEM_ESTABLISHED_DATE_TIME', None),
 'PRB_8': ('leaf', 'TS', 'ANTICIPATED_PROBLEM_RESOLUTION_DATE_TIME', None),
 'PRB_9': ('leaf', 'TS', 'ACTUAL_PROBLEM_RESOLUTION_DATE_TIME', None),
 'PRC_1': ('leaf', 'CE', 'PRIMARY_KEY_VALUE_PRC', None),
 'PRC_10': ('leaf', 'MO', 'MAXIMUM_PRICE', None),
 'PRC_11': ('leaf', 'TS', 'EFFECTIVE_START_DATE', None),
 'PRC_12': ('leaf', 'TS', 'EFFECTIVE_END_DATE', None),
 'PRC_13': ('leaf', 'IS', 'PRICE_OVERRIDE_FLAG', None),
 'PRC_14': ('leaf', 'CE', 'BILLING_CATEGORY', None),
 'PRC_15': ('leaf', 'ID', 'CHARGEABLE_FLAG', None),
 'PRC_16': ('leaf', 'ID', 'ACTIVE_INACTIVE_FLAG', None),
 'PRC_17': ('leaf', 'MO', 'COST', None),
 'PRC_18': ('leaf', 'IS', 'CHARGE_ON_INDICATOR', None),
 'PRC_2': ('leaf', 'CE', 'FACILITY_ID_PRC', None),
 'PRC_3': ('leaf', 'CE', 'DEPARTMENT', None),
 'PRC_4': ('leaf', 'IS', 'VALID_PATIENT_CLASSES', None),
 'PRC_5': ('leaf', 'CP', 'PRICE', None),
 'PRC_6': ('leaf', 'ST', 'FORMULA', None),
 'PRC_7': ('leaf', 'NM', 'MINIMUM_QUANTITY', None),
 'PRC_8': ('leaf', 'NM', 'MAXIMUM_QUANTITY', None),
 'PRC_9': ('leaf', 'MO', 'MINIMUM_PRICE', None),
 'PRD_1': ('leaf', 'CE', 'PROVIDER_ROLE', None),
 'PRD_2': ('leaf', 'XPN', 'PROVIDER_NAME', None),
 'PRD_3': ('leaf', 'XAD', 'PROVIDER_ADDRESS', None),
 'PRD_4': ('leaf', 'PL', 'PROVIDER_LOCATION', None),
 'PRD_5': ('leaf', 'XTN', 'PROVIDER_COMMUNICATION_INFORMATION', None),
 'PRD_6': ('leaf', 'CE', 'PREFERRED_METHOD_OF_CONTACT', None),
 'PRD_7': ('leaf', 'PI', 'PROVIDER_IDENTIFIERS', None),
 'PRD_8': ('leaf', 'TS', 'EFFECTIVE_START_DATE_OF_PROVIDER_ROLE', None),
 'PRD_9': ('leaf', 'TS', 'EFFECTIVE_END_DATE_OF_PROVIDER_ROLE', None),
 'PSH_1': ('leaf', 'ST', 'REPORT_TYPE', None),
 'PSH_10': ('leaf', 'CQ', 'QUANTITY_IN_USE', None),
 'PSH_11': ('leaf', 'ID', 'QUANTITY_IN_USE_METHOD', None),
 'PSH_12': ('leaf', 'FT', 'QUANTITY_IN_USE_COMMENT', None),
 'PSH_13': ('leaf',
            'NM',
            'NUMBER_OF_PRODUCT_EXPERIENCE_REPORTS_FILED_BY_FACILITY',
            None),
 'PSH_14': ('leaf',
            'NM',
            'NUMBER_OF_PRODUCT_EXPERIENCE_REPORTS_FILED_BY_DISTRIBUTOR',
            None),
 'PSH_2': ('leaf', 'ST', 'REPORT_FORM_IDENTIFIER', None),
 'PSH_3': ('leaf', 'TS', 'REPORT_DATE', None),
 'PSH_4': ('leaf', 'TS', 'REPORT_INTERVAL_START_DATE', None),
 'PSH_5': ('leaf', 'TS', 'REPORT_INTERVAL_END_DATE', None),
 'PSH_6': ('leaf', 'CQ', 'QUANTITY_MANUFACTURED', None),
 'PSH_7': ('leaf', 'CQ', 'QUANTITY_DISTRIBUTED', None),
 'PSH_8': ('leaf', 'ID', 'QUANTITY_DISTRIBUTED_METHOD', None),
 'PSH_9': ('leaf', 'FT', 'QUANTITY_DISTRIBUTED_COMMENT', None),
 'PTH_1': ('leaf', 'ID', 'ACTION_CODE', None),
 'PTH_2': ('leaf', 'CE', 'PATHWAY_ID', None),
 'PTH_3': ('leaf', 'EI', 'PATHWAY_INSTANCE_ID', None),
 'PTH_4': ('leaf', 'TS', 'PATHWAY_ESTABLISHED_DATE_TIME', None),
 'PTH_5': ('leaf', 'CE', 'PATHWAY_LIFE_CYCLE_STATUS', None),
 'PTH_6': ('leaf', 'TS', 'CHANGE_PATHWAY_LIFE_CYCLE_STATUS_DATE_TIME', None),
 'PV1_1': ('leaf', 'SI', 'SET_ID_PV1', None),
 'PV1_10': ('leaf', 'IS', 'HOSPITAL_SERVICE', None),
 'PV1_11': ('leaf', 'PL', 'TEMPORARY_LOCATION', None),
 'PV1_12': ('leaf', 'IS', 'PREADMIT_TEST_INDICATOR', None),
 'PV1_13': ('leaf', 'IS', 'RE_ADMISSION_INDICATOR', None),
 'PV1_14': ('leaf', 'IS', 'ADMIT_SOURCE', None),
 'PV1_15': ('leaf', 'IS', 'AMBULATORY_STATUS', None),
 'PV1_16': ('leaf', 'IS', 'VIP_INDICATOR', None),
 'PV1_17': ('leaf', 'XCN', 'ADMITTING_DOCTOR', None),
 'PV1_18': ('leaf', 'IS', 'PATIENT_TYPE', None),
 'PV1_19': ('leaf', 'CX', 'VISIT_NUMBER', None),
 'PV1_2': ('leaf', 'IS', 'PATIENT_CLASS', None),
 'PV1_20': ('leaf', 'FC', 'FINANCIAL_CLASS', None),
 'PV1_21': ('leaf', 'IS', 'CHARGE_PRICE_INDICATOR', None),
 'PV1_22': ('leaf', 'IS', 'COURTESY_CODE', None),
 'PV1_23': ('leaf', 'IS', 'CREDIT_RATING', None),
 'PV1_24': ('leaf', 'IS', 'CONTRACT_CODE', None),
 'PV1_25': ('leaf', 'DT', 'CONTRACT_EFFECTIVE_DATE', None),
 'PV1_26': ('leaf', 'NM', 'CONTRACT_AMOUNT', None),
 'PV1_27': ('leaf', 'NM', 'CONTRACT_PERIOD', None),
 'PV1_28': ('leaf', 'IS', 'INTEREST_CODE', None),
 'PV1_29': ('leaf', 'IS', 'TRANSFER_TO_BAD_DEBT_CODE', None),
 'PV1_3': ('leaf', 'PL', 'ASSIGNED_PATIENT_LOCATION', None),
 'PV1_30': ('leaf', 'DT', 'TRANSFER_TO_BAD_DEBT_DATE', None),
 'PV1_31': ('leaf', 'IS', 'BAD_DEBT_AGENCY_CODE', None),
 'PV1_32': ('leaf', 'NM', 'BAD_DEBT_TRANSFER_AMOUNT', None),
 'PV1_33': ('leaf', 'NM', 'BAD_DEBT_RECOVERY_AMOUNT', None),
 'PV1_34': ('leaf', 'IS', 'DELETE_ACCOUNT_INDICATOR', None),
 'PV1_35': ('leaf', 'DT', 'DELETE_ACCOUNT_DATE', None),
 'PV1_36': ('leaf', 'IS', 'DISCHARGE_DISPOSITION', None),
 'PV1_37': ('leaf', 'DLD', 'DISCHARGED_TO_LOCATION', None),
 'PV1_38': ('leaf', 'CE', 'DIET_TYPE', None),
 'PV1_39': ('leaf', 'IS', 'SERVICING_FACILITY', None),
 'PV1_4': ('leaf', 'IS', 'ADMISSION_TYPE', None),
 'PV1_40': ('leaf', 'IS', 'BED_STATUS', None),
 'PV1_41': ('leaf', 'IS', 'ACCOUNT_STATUS', None),
 'PV1_42': ('leaf', 'PL', 'PENDING_LOCATION', None),
 'PV1_43': ('leaf', 'PL', 'PRIOR_TEMPORARY_LOCATION', None),
 'PV1_44': ('leaf', 'TS', 'ADMIT_DATE_TIME', None),
 'PV1_45': ('leaf', 'TS', 'DISCHARGE_DATE_TIME', None),
 'PV1_46': ('leaf', 'NM', 'CURRENT_PATIENT_BALANCE', None),
 'PV1_47': ('leaf', 'NM', 'TOTAL_CHARGES', None),
 'PV1_48': ('leaf', 'NM', 'TOTAL_ADJUSTMENTS', None),
 'PV1_49': ('leaf', 'NM', 'TOTAL_PAYMENTS', None),
 'PV1_5': ('leaf', 'CX', 'PREADMIT_NUMBER', None),
 'PV1_50': ('leaf', 'CX', 'ALTERNATE_VISIT_ID', None),
 'PV1_51': ('leaf', 'IS', 'VISIT_INDICATOR', None),
 'PV1_52': ('leaf', 'XCN', 'OTHER_HEALTHCARE_PROVIDER', None),
 'PV1_6': ('leaf', 'PL', 'PRIOR_PATIENT_LOCATION', None),
 'PV1_7': ('leaf', 'XCN', 'ATTENDING_DOCTOR', None),
 'PV1_8': ('leaf', 'XCN', 'REFERRING_DOCTOR', None),
 'PV1_9': ('leaf', 'XCN', 'CONSULTING_DOCTOR', None),
 'PV2_1': ('leaf', 'PL', 'PRIOR_PENDING_LOCATION', None),
 'PV2_10': ('leaf', 'NM', 'ESTIMATED_LENGTH_OF_INPATIENT_STAY', None),
 'PV2_11': ('leaf', 'NM', 'ACTUAL_LENGTH_OF_INPATIENT_STAY', None),
 'PV2_12': ('leaf', 'ST', 'VISIT_DESCRIPTION', None),
 'PV2_13': ('leaf', 'XCN', 'REFERRAL_SOURCE_CODE', None),
 'PV2_14': ('leaf', 'DT', 'PREVIOUS_SERVICE_DATE', None),
 'PV2_15': ('leaf', 'ID', 'EMPLOYMENT_ILLNESS_RELATED_INDICATOR', None),
 'PV2_16': ('leaf', 'IS', 'PURGE_STATUS_CODE', None),
 'PV2_17': ('leaf', 'DT', 'PURGE_STATUS_DATE', None),
 'PV2_18': ('leaf', 'IS', 'SPECIAL_PROGRAM_CODE', None),
 'PV2_19': ('leaf', 'ID', 'RETENTION_INDICATOR', None),
 'PV2_2': ('leaf', 'CE', 'ACCOMMODATION_CODE', None),
 'PV2_20': ('leaf', 'NM', 'EXPECTED_NUMBER_OF_INSURANCE_PLANS', None),
 'PV2_21': ('leaf', 'IS', 'VISIT_PUBLICITY_CODE', None),
 'PV2_22': ('leaf', 'ID', 'VISIT_PROTECTION_INDICATOR', None),
 'PV2_23': ('leaf', 'XON', 'CLINIC_ORGANIZATION_NAME', None),
 'PV2_24': ('leaf', 'IS', 'PATIENT_STATUS_CODE', None),
 'PV2_25': ('leaf', 'IS', 'VISIT_PRIORITY_CODE', None),
 'PV2_26': ('leaf', 'DT', 'PREVIOUS_TREATMENT_DATE', None),
 'PV2_27': ('leaf', 'IS', 'EXPECTED_DISCHARGE_DISPOSITION', None),
 'PV2_28': ('leaf', 'DT', 'SIGNATURE_ON_FILE_DATE', None),
 'PV2_29': ('leaf', 'DT', 'FIRST_SIMILAR_ILLNESS_DATE', None),
 'PV2_3': ('leaf', 'CE', 'ADMIT_REASON', None),
 'PV2_30': ('leaf', 'CE', 'PATIENT_CHARGE_ADJUSTMENT_CODE', None),
 'PV2_31': ('leaf', 'IS', 'RECURRING_SERVICE_CODE', None),
 'PV2_32': ('leaf', 'ID', 'BILLING_MEDIA_CODE', None),
 'PV2_33': ('leaf', 'TS', 'EXPECTED_SURGERY_DATE_TIME', None),
 'PV2_34': ('leaf', 'ID', 'MILITARY_PARTNERSHIP_CODE', None),
 'PV2_35': ('leaf', 'ID', 'MILITARY_NON_AVAILABILITY_CODE', None),
 'PV2_36': ('leaf', 'ID', 'NEWBORN_BABY_INDICATOR', None),
 'PV2_37': ('leaf', 'ID', 'BABY_DETAINED_INDICATOR', None),
 'PV2_4': ('leaf', 'CE', 'TRANSFER_REASON', None),
 'PV2_5': ('leaf', 'ST', 'PATIENT_VALUABLES', None),
 'PV2_6': ('leaf', 'ST', 'PATIENT_VALUABLES_LOCATION', None),
 'PV2_7': ('leaf', 'IS', 'VISIT_USER_CODE', None),
 'PV2_8': ('leaf', 'TS', 'EXPECTED_ADMIT_DATE_TIME', None),
 'PV2_9': ('leaf', 'TS', 'EXPECTED_DISCHARGE_DATE_TIME', None),
 'QAK_1': ('leaf', 'ST', 'QUERY_TAG', None),
 'QAK_2': ('leaf', 'ID', 'QUERY_RESPONSE_STATUS', None),
 'QRD_1': ('leaf', 'TS', 'QUERY_DATE_TIME', None),
 'QRD_10': ('leaf', 'CE', 'WHAT_DEPARTMENT_DATA_CODE', None),
 'QRD_11': ('leaf', 'VR', 'WHAT_DATA_CODE_VALUE_QUAL_', None),
 'QRD_12': ('leaf', 'ID', 'QUERY_RESULTS_LEVEL', None),
 'QRD_2': ('leaf', 'ID', 'QUERY_FORMAT_CODE', None),
 'QRD_3': ('leaf', 'ID', 'QUERY_PRIORITY', None),
 'QRD_4': ('leaf', 'ST', 'QUERY_ID', None),
 'QRD_5': ('leaf', 'ID', 'DEFERRED_RESPONSE_TYPE', None),
 'QRD_6': ('leaf', 'TS', 'DEFERRED_RESPONSE_DATE_TIME', None),
 'QRD_7': ('leaf', 'CQ', 'QUANTITY_LIMITED_REQUEST', None),
 'QRD_8': ('leaf', 'XCN', 'WHO_SUBJECT_FILTER', None),
 'QRD_9': ('leaf', 'CE', 'WHAT_SUBJECT_FILTER', None),
 'QRF_1': ('leaf', 'ST', 'WHERE_SUBJECT_FILTER', None),
 'QRF_2': ('leaf', 'TS', 'WHEN_DATA_START_DATE_TIME', None),
 'QRF_3': ('leaf', 'TS', 'WHEN_DATA_END_DATE_TIME', None),
 'QRF_4': ('leaf', 'ST', 'WHAT_USER_QUALIFIER', None),
 'QRF_5': ('leaf', 'ST', 'OTHER_QRY_SUBJECT_FILTER', None),
 'QRF_6': ('leaf', 'ID', 'WHICH_DATE_TIME_QUALIFIER', None),
 'QRF_7': ('leaf', 'ID', 'WHICH_DATE_TIME_STATUS_QUALIFIER', None),
 'QRF_8': ('leaf', 'ID', 'DATE_TIME_SELECTION_QUALIFIER', None),
 'QRF_9': ('leaf', 'TQ', 'WHEN_QUANTITY_TIMING_QUALIFIER', None),
 'RDF_1': ('leaf', 'NM', 'NUMBER_OF_COLUMNS_PER_ROW', None),
 'RDF_2': ('leaf', 'RCD', 'COLUMN_DESCRIPTION', None),
 'RDT_1': ('leaf', 'varies', 'COLUMN_VALUE', None),
 'RF1_1': ('leaf', 'CE', 'REFERRAL_STATUS', None),
 'RF1_10': ('leaf', 'CE', 'REFERRAL_REASON', None),
 'RF1_11': ('leaf', 'EI', 'EXTERNAL_REFERRAL_IDENTIFIER', None),
 'RF1_2': ('leaf', 'CE', 'REFERRAL_PRIORITY', None),
 'RF1_3': ('leaf', 'CE', 'REFERRAL_TYPE', None),
 'RF1_4': ('leaf', 'CE', 'REFERRAL_DISPOSITION', None),
 'RF1_5': ('leaf', 'CE', 'REFERRAL_CATEGORY', None),
 'RF1_6': ('leaf', 'EI', 'ORIGINATING_REFERRAL_IDENTIFIER', None),
 'RF1_7': ('leaf', 'TS', 'EFFECTIVE_DATE', None),
 'RF1_8': ('leaf', 'TS', 'EXPIRATION_DATE', None),
 'RF1_9': ('leaf', 'TS', 'PROCESS_DATE', None),
 'RGS_1': ('leaf', 'SI', 'SET_ID_RGS', None),
 'RGS_2': ('leaf', 'ID', 'SEGMENT_ACTION_CODE', None),
 'RGS_3': ('leaf', 'CE', 'RESOURCE_GROUP_ID', None),
 'ROL_1': ('leaf', 'EI', 'ROLE_INSTANCE_ID', None),
 'ROL_2': ('leaf', 'ID', 'ACTION_CODE', None),
 'ROL_3': ('leaf', 'CE', 'ROLE_ROL', None),
 'ROL_4': ('leaf', 'XCN', 'ROLE_PERSON', None),
 'ROL_5': ('leaf', 'TS', 'ROLE_BEGIN_DATE_TIME', None),
 'ROL_6': ('leaf', 'TS', 'ROLE_END_DATE_TIME', None),
 'ROL_7': ('leaf', 'CE', 'ROLE_DURATION', None),
 'ROL_8': ('leaf', 'CE', 'ROLE_ACTION_REASON', None),
 'RQ1_1': ('leaf', 'ST', 'ANTICIPATED_PRICE', None),
 'RQ1_2': ('leaf', 'CE', 'MANUFACTURER_ID', None),
 'RQ1_3': ('leaf', 'ST', u'MANUFACTURER_S_CATALOG', None),
 'RQ1_4': ('leaf', 'CE', 'VENDOR_ID', None),
 'RQ1_5': ('leaf', 'ST', 'VENDOR_CATALOG', None),
 'RQ1_6': ('leaf', 'ID', 'TAXABLE', None),
 'RQ1_7': ('leaf', 'ID', 'SUBSTITUTE_ALLOWED', None),
 'RQD_1': ('leaf', 'SI', 'REQUISITION_LINE_NUMBER', None),
 'RQD_10': ('leaf', 'DT', 'DATE_NEEDED', None),
 'RQD_2': ('leaf', 'CE', 'ITEM_CODE_INTERNAL', None),
 'RQD_3': ('leaf', 'CE', 'ITEM_CODE_EXTERNAL', None),
 'RQD_4': ('leaf', 'CE', 'HOSPITAL_ITEM_CODE', None),
 'RQD_5': ('leaf', 'NM', 'REQUISITION_QUANTITY', None),
 'RQD_6': ('leaf', 'CE', 'REQUISITION_UNIT_OF_MEASURE', None),
 'RQD_7': ('leaf', 'IS', 'DEPT_COST_CENTER', None),
 'RQD_8': ('leaf', 'IS', 'ITEM_NATURAL_ACCOUNT_CODE', None),
 'RQD_9': ('leaf', 'CE', 'DELIVER_TO_ID', None),
 'RXA_1': ('leaf', 'NM', 'GIVE_SUB_ID_COUNTER', None),
 'RXA_10': ('leaf', 'XCN', 'ADMINISTERING_PROVIDER', None),
 'RXA_11': ('leaf', 'LA2', 'ADMINISTERED_AT_LOCATION', None),
 'RXA_12': ('leaf', 'ST', 'ADMINISTERED_PER_TIME_UNIT_', None),
 'RXA_13': ('leaf', 'NM', 'ADMINISTERED_STRENGTH', None),
 'RXA_14': ('leaf', 'CE', 'ADMINISTERED_STRENGTH_UNITS', None),
 'RXA_15': ('leaf', 'ST', 'SUBSTANCE_LOT_NUMBER', None),
 'RXA_16': ('leaf', 'TS', 'SUBSTANCE_EXPIRATION_DATE', None),
 'RXA_17': ('leaf', 'CE', 'SUBSTANCE_MANUFACTURER_NAME', None),
 'RXA_18': ('leaf', 'CE', 'SUBSTANCE_REFUSAL_REASON', None),
 'RXA_19': ('leaf', 'CE', 'INDICATION', None),
 'RXA_2': ('leaf', 'NM', 'ADMINISTRATION_SUB_ID_COUNTER', None),
 'RXA_20': ('leaf', 'ID', 'COMPLETION_STATUS', None),
 'RXA_21': ('leaf', 'ID', 'ACTION_CODE_RXA', None),
 'RXA_22': ('leaf', 'TS', 'SYSTEM_ENTRY_DATE_TIME', None),
 'RXA_3': ('leaf', 'TS', 'DATE_TIME_START_OF_ADMINISTRATION', None),
 'RXA_4': ('leaf', 'TS', 'DATE_TIME_END_OF_ADMINISTRATION', None),
 'RXA_5': ('leaf', 'CE', 'ADMINISTERED_CODE', None),
 'RXA_6': ('leaf', 'NM', 'ADMINISTERED_AMOUNT', None),
 'RXA_7': ('leaf', 'CE', 'ADMINISTERED_UNITS', None),
 'RXA_8': ('leaf', 'CE', 'ADMINISTERED_DOSAGE_FORM', None),
 'RXA_9': ('leaf', 'CE', 'ADMINISTRATION_NOTES', None),
 'RXC_1': ('leaf', 'ID', 'RX_COMPONENT_TYPE', None),
 'RXC_2': ('leaf', 'CE', 'COMPONENT_CODE', None),
 'RXC_3': ('leaf', 'NM', 'COMPONENT_AMOUNT', None),
 'RXC_4': ('leaf', 'CE', 'COMPONENT_UNITS', None),
 'RXC_5': ('leaf', 'NM', 'COMPONENT_STRENGTH', None),
 'RXC_6': ('leaf', 'CE', 'COMPONENT_STRENGTH_UNITS', None),
 'RXD_1': ('leaf', 'NM', 'DISPENSE_SUB_ID_COUNTER', None),
 'RXD_10': ('leaf', 'XCN', 'DISPENSING_PROVIDER', None),
 'RXD_11': ('leaf', 'ID', 'SUBSTITUTION_STATUS', None),
 'RXD_12': ('leaf', 'CQ', 'TOTAL_DAILY_DOSE', None),
 'RXD_13': ('leaf', 'LA2', 'DISPENSE_TO_LOCATION', None),
 'RXD_14': ('leaf', 'ID', 'NEEDS_HUMAN_REVIEW', None),
 'RXD_15': ('leaf',
            'CE',
            u'PHARMACY_TREATMENT_SUPPLIER_S_SPECIAL_DISPENSING_INSTRUCTIONS',
            None),
 'RXD_16': ('leaf', 'NM', 'ACTUAL_STRENGTH', None),
 'RXD_17': ('leaf', 'CE', 'ACTUAL_STRENGTH_UNIT', None),
 'RXD_18': ('leaf', 'ST', 'SUBSTANCE_LOT_NUMBER', None),
 'RXD_19': ('leaf', 'TS', 'SUBSTANCE_EXPIRATION_DATE', None),
 'RXD_2': ('leaf', 'CE', 'DISPENSE_GIVE_CODE', None),
 'RXD_20': ('leaf', 'CE', 'SUBSTANCE_MANUFACTURER_NAME', None),
 'RXD_21': ('leaf', 'CE', 'INDICATION', None),
 'RXD_22': ('leaf', 'NM', 'DISPENSE_PACKAGE_SIZE', None),
 'RXD_23': ('leaf', 'CE', 'DISPENSE_PACKAGE_SIZE_UNIT', None),
 'RXD_24': ('leaf', 'ID', 'DISPENSE_PACKAGE_METHOD', None),
 'RXD_3': ('leaf', 'TS', 'DATE_TIME_DISPENSED', None),
 'RXD_4': ('leaf', 'NM', 'ACTUAL_DISPENSE_AMOUNT', None),
 'RXD_5': ('leaf', 'CE', 'ACTUAL_DISPENSE_UNITS', None),
 'RXD_6': ('leaf', 'CE', 'ACTUAL_DOSAGE_FORM', None),
 'RXD_7': ('leaf', 'ST', 'PRESCRIPTION_NUMBER', None),
 'RXD_8': ('leaf', 'NM', 'NUMBER_OF_REFILLS_REMAINING', None),
 'RXD_9': ('leaf', 'ST', 'DISPENSE_NOTES', None),
 'RXE_1': ('leaf', 'TQ', 'QUANTITY_TIMING', None),
 'RXE_10': ('leaf', 'NM', 'DISPENSE_AMOUNT', None),
 'RXE_11': ('leaf', 'CE', 'DISPENSE_UNITS', None),
 'RXE_12': ('leaf', 'NM', 'NUMBER_OF_REFILLS', None),
 'RXE_13': ('leaf', 'XCN', u'ORDERING_PROVIDER_S_DEA_NUMBER', None),
 'RXE_14': ('leaf',
            'XCN',
            u'PHARMACIST_TREATMENT_SUPPLIER_S_VERIFIER_ID',
            None),
 'RXE_15': ('leaf', 'ST', 'PRESCRIPTION_NUMBER', None),
 'RXE_16': ('leaf', 'NM', 'NUMBER_OF_REFILLS_REMAINING', None),
 'RXE_17': ('leaf', 'NM', 'NUMBER_OF_REFILLS_DOSES_DISPENSED', None),
 'RXE_18': ('leaf', 'TS', 'D_T_OF_MOST_RECENT_REFILL_OR_DOSE_DISPENSED', None),
 'RXE_19': ('leaf', 'CQ', 'TOTAL_DAILY_DOSE', None),
 'RXE_2': ('leaf', 'CE', 'GIVE_CODE', None),
 'RXE_20': ('leaf', 'ID', 'NEEDS_HUMAN_REVIEW', None),
 'RXE_21': ('leaf',
            'CE',
            u'PHARMACY_TREATMENT_SUPPLIER_S_SPECIAL_DISPENSING_INSTRUCTIONS',
            None),
 'RXE_22': ('leaf', 'ST', 'GIVE_PER_TIME_UNIT_', None),
 'RXE_23': ('leaf', 'ST', 'GIVE_RATE_AMOUNT', None),
 'RXE_24': ('leaf', 'CE', 'GIVE_RATE_UNITS', None),
 'RXE_25': ('leaf', 'NM', 'GIVE_STRENGTH', None),
 'RXE_26': ('leaf', 'CE', 'GIVE_STRENGTH_UNITS', None),
 'RXE_27': ('leaf', 'CE', 'GIVE_INDICATION', None),
 'RXE_28': ('leaf', 'NM', 'DISPENSE_PACKAGE_SIZE', None),
 'RXE_29': ('leaf', 'CE', 'DISPENSE_PACKAGE_SIZE_UNIT', None),
 'RXE_3': ('leaf', 'NM', 'GIVE_AMOUNT_MINIMUM', None),
 'RXE_30': ('leaf', 'ID', 'DISPENSE_PACKAGE_METHOD', None),
 'RXE_4': ('leaf', 'NM', 'GIVE_AMOUNT_MAXIMUM', None),
 'RXE_5': ('leaf', 'CE', 'GIVE_UNITS', None),
 'RXE_6': ('leaf', 'CE', 'GIVE_DOSAGE_FORM', None),
 'RXE_7': ('leaf', 'CE', u'PROVIDER_S_ADMINISTRATION_INSTRUCTIONS', None),
 'RXE_8': ('leaf', 'LA1', 'DELIVER_TO_LOCATION', None),
 'RXE_9': ('leaf', 'ID', 'SUBSTITUTION_STATUS', None),
 'RXG_1': ('leaf', 'NM', 'GIVE_SUB_ID_COUNTER', None),
 'RXG_10': ('leaf', 'ID', 'SUBSTITUTION_STATUS', None),
 'RXG_11': ('leaf', 'LA2', 'DISPENSE_TO_LOCATION', None),
 'RXG_12': ('leaf', 'ID', 'NEEDS_HUMAN_REVIEW', None),
 'RXG_13': ('leaf',
            'CE',
            u'PHARMACY_TREATMENT_SUPPLIER_S_SPECIAL_ADMINISTRATION_INSTRUCTIONS',
            None),
 'RXG_14': ('leaf', 'ST', 'GIVE_PER_TIME_UNIT_', None),
 'RXG_15': ('leaf', 'ST', 'GIVE_RATE_AMOUNT', None),
 'RXG_16': ('leaf', 'CE', 'GIVE_RATE_UNITS', None),
 'RXG_17': ('leaf', 'NM', 'GIVE_STRENGTH', None),
 'RXG_18': ('leaf', 'CE', 'GIVE_STRENGTH_UNITS', None),
 'RXG_19': ('leaf', 'ST', 'SUBSTANCE_LOT_NUMBER', None),
 'RXG_2': ('leaf', 'NM', 'DISPENSE_SUB_ID_COUNTER', None),
 'RXG_20': ('leaf', 'TS', 'SUBSTANCE_EXPIRATION_DATE', None),
 'RXG_21': ('leaf', 'CE', 'SUBSTANCE_MANUFACTURER_NAME', None),
 'RXG_22': ('leaf', 'CE', 'INDICATION', None),
 'RXG_3': ('leaf', 'TQ', 'QUANTITY_TIMING', None),
 'RXG_4': ('leaf', 'CE', 'GIVE_CODE', None),
 'RXG_5': ('leaf', 'NM', 'GIVE_AMOUNT_MINIMUM', None),
 'RXG_6': ('leaf', 'NM', 'GIVE_AMOUNT_MAXIMUM', None),
 'RXG_7': ('leaf', 'CE', 'GIVE_UNITS', None),
 'RXG_8': ('leaf', 'CE', 'GIVE_DOSAGE_FORM', None),
 'RXG_9': ('leaf', 'CE', 'ADMINISTRATION_NOTES', None),
 'RXO_1': ('leaf', 'CE', 'REQUESTED_GIVE_CODE', None),
 'RXO_10': ('leaf', 'CE', 'REQUESTED_DISPENSE_CODE', None),
 'RXO_11': ('leaf', 'NM', 'REQUESTED_DISPENSE_AMOUNT', None),
 'RXO_12': ('leaf', 'CE', 'REQUESTED_DISPENSE_UNITS', None),
 'RXO_13': ('leaf', 'NM', 'NUMBER_OF_REFILLS', None),
 'RXO_14': ('leaf', 'XCN', u'ORDERING_PROVIDER_S_DEA_NUMBER', None),
 'RXO_15': ('leaf',
            'XCN',
            u'PHARMACIST_TREATMENT_SUPPLIER_S_VERIFIER_ID',
            None),
 'RXO_16': ('leaf', 'ID', 'NEEDS_HUMAN_REVIEW', None),
 'RXO_17': ('leaf', 'ST', 'REQUESTED_GIVE_PER_TIME_UNIT_', None),
 'RXO_18': ('leaf', 'NM', 'REQUESTED_GIVE_STRENGTH', None),
 'RXO_19': ('leaf', 'CE', 'REQUESTED_GIVE_STRENGTH_UNITS', None),
 'RXO_2': ('leaf', 'NM', 'REQUESTED_GIVE_AMOUNT_MINIMUM', None),
 'RXO_20': ('leaf', 'CE', 'INDICATION', None),
 'RXO_21': ('leaf', 'ST', 'REQUESTED_GIVE_RATE_AMOUNT', None),
 'RXO_22': ('leaf', 'CE', 'REQUESTED_GIVE_RATE_UNITS', None),
 'RXO_23': ('leaf', 'CQ', 'TOTAL_DAILY_DOSE', None),
 'RXO_3': ('leaf', 'NM', 'REQUESTED_GIVE_AMOUNT_MAXIMUM', None),
 'RXO_4': ('leaf', 'CE', 'REQUESTED_GIVE_UNITS', None),
 'RXO_5': ('leaf', 'CE', 'REQUESTED_DOSAGE_FORM', None),
 'RXO_6': ('leaf', 'CE', u'PROVIDER_S_PHARMACY_TREATMENT_INSTRUCTIONS', None),
 'RXO_7': ('leaf', 'CE', u'PROVIDER_S_ADMINISTRATION_INSTRUCTIONS', None),
 'RXO_8': ('leaf', 'LA1', 'DELIVER_TO_LOCATION', None),
 'RXO_9': ('leaf', 'ID', 'ALLOW_SUBSTITUTIONS', None),
 'RXR_1': ('leaf', 'CE', 'ROUTE', None),
 'RXR_2': ('leaf', 'CE', 'SITE', None),
 'RXR_3': ('leaf', 'CE', 'ADMINISTRATION_DEVICE', None),
 'RXR_4': ('leaf', 'CE', 'ADMINISTRATION_METHOD', None),
 'RXR_5': ('leaf', 'CE', 'ROUTING_INSTRUCTION', None),
 'SCH_1': ('leaf', 'EI', 'PLACER_APPOINTMENT_ID', None),
 'SCH_10': ('leaf', 'CE', 'APPOINTMENT_DURATION_UNITS', None),
 'SCH_11': ('leaf', 'TQ', 'APPOINTMENT_TIMING_QUANTITY', None),
 'SCH_12': ('leaf', 'XCN', 'PLACER_CONTACT_PERSON', None),
 'SCH_13': ('leaf', 'XTN', 'PLACER_CONTACT_PHONE_NUMBER', None),
 'SCH_14': ('leaf', 'XAD', 'PLACER_CONTACT_ADDRESS', None),
 'SCH_15': ('leaf', 'PL', 'PLACER_CONTACT_LOCATION', None),
 'SCH_16': ('leaf', 'XCN', 'FILLER_CONTACT_PERSON', None),
 'SCH_17': ('leaf', 'XTN', 'FILLER_CONTACT_PHONE_NUMBER', None),
 'SCH_18': ('leaf', 'XAD', 'FILLER_CONTACT_ADDRESS', None),
 'SCH_19': ('leaf', 'PL', 'FILLER_CONTACT_LOCATION', None),
 'SCH_2': ('leaf', 'EI', 'FILLER_APPOINTMENT_ID', None),
 'SCH_20': ('leaf', 'XCN', 'ENTERED_BY_PERSON', None),
 'SCH_21': ('leaf', 'XTN', 'ENTERED_BY_PHONE_NUMBER', None),
 'SCH_22': ('leaf', 'PL', 'ENTERED_BY_LOCATION', None),
 'SCH_23': ('leaf', 'EI', 'PARENT_PLACER_APPOINTMENT_ID', None),
 'SCH_24': ('leaf', 'EI', 'PARENT_FILLER_APPOINTMENT_ID', None),
 'SCH_25': ('leaf', 'CE', 'FILLER_STATUS_CODE', None),
 'SCH_3': ('leaf', 'NM', 'OCCURRENCE_NUMBER', None),
 'SCH_4': ('leaf', 'EI', 'PLACER_GROUP_NUMBER', None),
 'SCH_5': ('leaf', 'CE', 'SCHEDULE_ID', None),
 'SCH_6': ('leaf', 'CE', 'EVENT_REASON', None),
 'SCH_7': ('leaf', 'CE', 'APPOINTMENT_REASON', None),
 'SCH_8': ('leaf', 'CE', 'APPOINTMENT_TYPE', None),
 'SCH_9': ('leaf', 'NM', 'APPOINTMENT_DURATION', None),
 'SPR_1': ('leaf', 'ST', 'QUERY_TAG', None),
 'SPR_2': ('leaf', 'ID', 'QUERY_RESPONSE_FORMAT_CODE', None),
 'SPR_3': ('leaf', 'CE', 'STORED_PROCEDURE_NAME', None),
 'SPR_4': ('leaf', 'QIP', 'INPUT_PARAMETER_LIST', None),
 'STF_1': ('leaf', 'CE', 'PRIMARY_KEY_VALUE_STF', None),
 'STF_10': ('leaf', 'XTN', 'PHONE', None),
 'STF_11': ('leaf', 'XAD', 'OFFICE_HOME_ADDRESS', None),
 'STF_12': ('leaf', 'DIN', 'INSTITUTION_ACTIVATION_DATE', None),
 'STF_13': ('leaf', 'DIN', 'INSTITUTION_INACTIVATION_DATE', None),
 'STF_14': ('leaf', 'CE', 'BACKUP_PERSON_ID', None),
 'STF_15': ('leaf', 'ST', 'E_MAIL_ADDRESS', None),
 'STF_16': ('leaf', 'CE', 'PREFERRED_METHOD_OF_CONTACT', None),
 'STF_17': ('leaf', 'CE', 'MARITAL_STATUS', None),
 'STF_18': ('leaf', 'ST', 'JOB_TITLE', None),
 'STF_19': ('leaf', 'JCC', 'JOB_CODE_CLASS', None),
 'STF_2': ('leaf', 'CX', 'STAFF_ID_CODE', None),
 'STF_20': ('leaf', 'IS', 'EMPLOYMENT_STATUS', None),
 'STF_21': ('leaf', 'ID', 'ADDITIONAL_INSURED_ON_AUTO', None),
 'STF_22': ('leaf', 'DLN', u'DRIVER_S_LICENSE_NUMBER_STAFF', None),
 'STF_23': ('leaf', 'ID', 'COPY_AUTO_INS', None),
 'STF_24': ('leaf', 'DT', 'AUTO_INS_EXPIRES', None),
 'STF_25': ('leaf', 'DT', 'DATE_LAST_DMV_REVIEW', None),
 'STF_26': ('leaf', 'DT', 'DATE_NEXT_DMV_REVIEW', None),
 'STF_3': ('leaf', 'XPN', 'STAFF_NAME', None),
 'STF_4': ('leaf', 'IS', 'STAFF_TYPE', None),
 'STF_5': ('leaf', 'IS', 'SEX', None),
 'STF_6': ('leaf', 'TS', 'DATE_TIME_OF_BIRTH', None),
 'STF_7': ('leaf', 'ID', 'ACTIVE_INACTIVE_FLAG', None),
 'STF_8': ('leaf', 'CE', 'DEPARTMENT', None),
 'STF_9': ('leaf', 'CE', 'HOSPITAL_SERVICE', None),
 'TXA_1': ('leaf', 'SI', 'SET_ID_TXA', None),
 'TXA_10': ('leaf', 'XCN', 'ASSIGNED_DOCUMENT_AUTHENTICATOR', None),
 'TXA_11': ('leaf', 'XCN', 'TRANSCRIPTIONIST_CODE_NAME', None),
 'TXA_12': ('leaf', 'EI', 'UNIQUE_DOCUMENT_NUMBER', None),
 'TXA_13': ('leaf', 'EI', 'PARENT_DOCUMENT_NUMBER', None),
 'TXA_14': ('leaf', 'EI', 'PLACER_ORDER_NUMBER', None),
 'TXA_15': ('leaf', 'EI', 'FILLER_ORDER_NUMBER', None),
 'TXA_16': ('leaf', 'ST', 'UNIQUE_DOCUMENT_FILE_NAME', None),
 'TXA_17': ('leaf', 'ID', 'DOCUMENT_COMPLETION_STATUS', None),
 'TXA_18': ('leaf', 'ID', 'DOCUMENT_CONFIDENTIALITY_STATUS', None),
 'TXA_19': ('leaf', 'ID', 'DOCUMENT_AVAILABILITY_STATUS', None),
 'TXA_2': ('leaf', 'IS', 'DOCUMENT_TYPE', None),
 'TXA_20': ('leaf', 'ID', 'DOCUMENT_STORAGE_STATUS', None),
 'TXA_21': ('leaf', 'ST', 'DOCUMENT_CHANGE_REASON', None),
 'TXA_22': ('leaf', 'PPN', 'AUTHENTICATION_PERSON_TIME_STAMP', None),
 'TXA_23': ('leaf',
            'XCN',
            'DISTRIBUTED_COPIES_CODE_AND_NAME_OF_RECIPIENTS_',
            None),
 'TXA_3': ('leaf', 'ID', 'DOCUMENT_CONTENT_PRESENTATION', None),
 'TXA_4': ('leaf', 'TS', 'ACTIVITY_DATE_TIME', None),
 'TXA_5': ('leaf', 'XCN', 'PRIMARY_ACTIVITY_PROVIDER_CODE_NAME', None),
 'TXA_6': ('leaf', 'TS', 'ORIGINATION_DATE_TIME', None),
 'TXA_7': ('leaf', 'TS', 'TRANSCRIPTION_DATE_TIME', None),
 'TXA_8': ('leaf', 'TS', 'EDIT_DATE_TIME', None),
 'TXA_9': ('leaf', 'XCN', 'ORIGINATOR_CODE_NAME', None),
 'UB1_1': ('leaf', 'SI', 'SET_ID_UB1', None),
 'UB1_10': ('leaf', 'UVC', 'VALUE_AMOUNT_CODE_46_49_', None),
 'UB1_11': ('leaf', 'NM', 'NUMBER_OF_GRACE_DAYS_90_', None),
 'UB1_12': ('leaf', 'CE', 'SPECIAL_PROGRAM_INDICATOR_44_', None),
 'UB1_13': ('leaf', 'CE', 'PSRO_UR_APPROVAL_INDICATOR_87_', None),
 'UB1_14': ('leaf', 'DT', 'PSRO_UR_APPROVED_STAY_FM_88_', None),
 'UB1_15': ('leaf', 'DT', 'PSRO_UR_APPROVED_STAY_TO_89_', None),
 'UB1_16': ('leaf', 'OCD', 'OCCURRENCE_28_32_', None),
 'UB1_17': ('leaf', 'CE', 'OCCURRENCE_SPAN_33_', None),
 'UB1_18': ('leaf', 'DT', 'OCCUR_SPAN_START_DATE_33_', None),
 'UB1_19': ('leaf', 'DT', 'OCCUR_SPAN_END_DATE_33_', None),
 'UB1_2': ('leaf', 'NM', 'BLOOD_DEDUCTIBLE_43_', None),
 'UB1_20': ('leaf', 'ST', 'UB_82_LOCATOR_2', None),
 'UB1_21': ('leaf', 'ST', 'UB_82_LOCATOR_9', None),
 'UB1_22': ('leaf', 'ST', 'UB_82_LOCATOR_27', None),
 'UB1_23': ('leaf', 'ST', 'UB_82_LOCATOR_45', None),
 'UB1_3': ('leaf', 'NM', 'BLOOD_FURNISHED_PINTS_OF_40_', None),
 'UB1_4': ('leaf', 'NM', 'BLOOD_REPLACED_PINTS_41_', None),
 'UB1_5': ('leaf', 'NM', 'BLOOD_NOT_REPLACED_PINTS_42_', None),
 'UB1_6': ('leaf', 'NM', 'CO_INSURANCE_DAYS_25_', None),
 'UB1_7': ('leaf', 'IS', 'CONDITION_CODE_35_39_', None),
 'UB1_8': ('leaf', 'NM', 'COVERED_DAYS_23_', None),
 'UB1_9': ('leaf', 'NM', 'NON_COVERED_DAYS_24_', None),
 'UB2_1': ('leaf', 'SI', 'SET_ID_UB2', None),
 'UB2_10': ('leaf', 'ST', 'UB92_LOCATOR_11_STATE_', None),
 'UB2_11': ('leaf', 'ST', 'UB92_LOCATOR_31_NATIONAL_', None),
 'UB2_12': ('leaf', 'ST', 'DOCUMENT_CONTROL_NUMBER', None),
 'UB2_13': ('leaf', 'ST', 'UB92_LOCATOR_49_NATIONAL_', None),
 'UB2_14': ('leaf', 'ST', 'UB92_LOCATOR_56_STATE_', None),
 'UB2_15': ('leaf', 'ST', 'UB92_LOCATOR_57_NATIONAL_', None),
 'UB2_16': ('leaf', 'ST', 'UB92_LOCATOR_78_STATE_', None),
 'UB2_17': ('leaf', 'NM', 'SPECIAL_VISIT_COUNT', None),
 'UB2_2': ('leaf', 'ST', 'CO_INSURANCE_DAYS_9_', None),
 'UB2_3': ('leaf', 'IS', 'CONDITION_CODE_24_30_', None),
 'UB2_4': ('leaf', 'ST', 'COVERED_DAYS_7_', None),
 'UB2_5': ('leaf', 'ST', 'NON_COVERED_DAYS_8_', None),
 'UB2_6': ('leaf', 'UVC', 'VALUE_AMOUNT_CODE', None),
 'UB2_7': ('leaf', 'OCD', 'OCCURRENCE_CODE_DATE_32_35_', None),
 'UB2_8': ('leaf', 'OSP', 'OCCURRENCE_SPAN_CODE_DATES_36_', None),
 'UB2_9': ('leaf', 'ST', 'UB92_LOCATOR_2_STATE_', None),
 'URD_1': ('leaf', 'TS', 'R_U_DATE_TIME', None),
 'URD_2': ('leaf', 'ID', 'REPORT_PRIORITY', None),
 'URD_3': ('leaf', 'XCN', 'R_U_WHO_SUBJECT_DEFINITION', None),
 'URD_4': ('leaf', 'CE', 'R_U_WHAT_SUBJECT_DEFINITION', None),
 'URD_5': ('leaf', 'CE', 'R_U_WHAT_DEPARTMENT_CODE', None),
 'URD_6': ('leaf', 'ST', 'R_U_DISPLAY_PRINT_LOCATIONS', None),
 'URD_7': ('leaf', 'ID', 'R_U_RESULTS_LEVEL', None),
 'URS_1': ('leaf', 'ST', 'R_U_WHERE_SUBJECT_DEFINITION', None),
 'URS_2': ('leaf', 'TS', 'R_U_WHEN_DATA_START_DATE_TIME', None),
 'URS_3': ('leaf', 'TS', 'R_U_WHEN_DATA_END_DATE_TIME', None),
 'URS_4': ('leaf', 'ST', 'R_U_WHAT_USER_QUALIFIER', None),
 'URS_5': ('leaf', 'ST', 'R_U_OTHER_RESULTS_SUBJECT_DEFINITION', None),
 'URS_6': ('leaf', 'ID', 'R_U_WHICH_DATE_TIME_QUALIFIER', None),
 'URS_7': ('leaf', 'ID', 'R_U_WHICH_DATE_TIME_STATUS_QUALIFIER', None),
 'URS_8': ('leaf', 'ID', 'R_U_DATE_TIME_SELECTION_QUALIFIER', None),
 'URS_9': ('leaf', 'TQ', 'R_U_QUANTITY_TIMING_QUALIFIER', None),
 'VAR_1': ('leaf', 'EI', 'VARIANCE_INSTANCE_ID', None),
 'VAR_2': ('leaf', 'TS', 'DOCUMENTED_DATE_TIME', None),
 'VAR_3': ('leaf', 'TS', 'STATED_VARIANCE_DATE_TIME', None),
 'VAR_4': ('leaf', 'XCN', 'VARIANCE_ORIGINATOR', None),
 'VAR_5': ('leaf', 'CE', 'VARIANCE_CLASSIFICATION', None),
 'VAR_6': ('leaf', 'ST', 'VARIANCE_DESCRIPTION', None),
 'VTQ_1': ('leaf', 'ST', 'QUERY_TAG', None),
 'VTQ_2': ('leaf', 'ID', 'QUERY_RESPONSE_FORMAT_CODE', None),
 'VTQ_3': ('leaf', 'CE', 'VT_QUERY_NAME', None),
 'VTQ_4': ('leaf', 'CE', 'VIRTUAL_TABLE_NAME', None),
 'VTQ_5': ('leaf', 'QSC', 'SELECTION_CRITERIA', None)}
